define(function(require, exports, module) {

	var FILE = require('file');
	var TIME = require('time');
	var RECORD = require('record');
	var BUSINESS = require('business');

	var vm = new Vue({
		el: '#vm',
		template: _g.getTemplate('Annex/annex-audio-frame-v'),
		data: {
			'startTime': 0,
			'endTime': 0,
			'speedTime': '',
			'secondTime': 0, // 录音时长（毫秒）
			'maxTime': 600000, // 录音最长时间
			'fileUrl': '', // 录音文件地址
			'isRecording': true, // 未录制状态
			'hideRecordMode': true, // 录制模式
			'isPlay': false, // 正在播放,
			'fileName': '',
			'fileType': '',
			'file':'',
			'isEdit': api.pageParam.data.isEdit,
			'itemIndex': api.pageParam.data.itemIndex, // 附件元素序号（编辑）
			'readOnly': api.pageParam.readOnly || false,
		},
		methods: {
			recording: function() { // 录音
				var self = this;
				self.hideRecordMode = false;
				var time = new Date();
				self.startTime = time.getTime();
				RECORD.start(); //开始录音
				setTimeout(function() { //时长限制
					self.stopRecording(); //停止录制
					_g.toastMsg({
						msg: '录制时间已经超过最长10分钟'
					});
				}, self.maxTime);
			},
			stopRecording: function() { // 停止录音
				var self = this;
				var time = new Date();
				self.endTime = time.getTime();
				var speedTime = self.secondTime = self.endTime - self.startTime;
				if (speedTime >= 1000) { // 录制成功
					self.hideRecordMode = true;
					self.isRecording = false;
					RECORD.stop({
						success: function(ret) {
							self.fileUrl = ret.path; //录音地址
							console.log('录音地址：' + self.fileUrl);
							self.speedTime = TIME.millisecondToDate(speedTime);
							var fileName = FILE.getFullNameByPath(ret.path);
							self.fileName = fileName.substring(0, fileName.lastIndexOf('.'));
						}
					});
				} else { // 录制时间过短
					self.hideRecordMode = true;
					_g.toastMsg({
						msg: '录制时间过短'
					});
				}
			},
			delRecord: function() { // 删除录音
				var self = this;
				_g.confirm({
					params: {
						title: '',
						msg: '是否删除该录音?',
						buttons: ['确定', '取消']
					},
					success: function(ret) {
						if (ret.buttonIndex == 1) {
							self.isRecording = true;
							self.fileUrl = '';
							self.fileName = '';
						}
					}
				});
			},
			autoDownload: function() { // 默认自动下载
				var self = this;
				var savePath = 'fs://download/' + self.file;
				console.log(savePath);
				console.log('下载地址：' + self.fileUrl + '，下载位置：' + savePath);
				FILE.download({
					url: self.fileUrl,
					savePath: savePath,
					success: function(ret) {
						console.log('下载成功');
						self.fileUrl = savePath;
					}
				});
			},
			playRecord: function() { //播放录音
				var self = this;
				if (!self.isPlay && self.fileUrl != '') {
					this.isPlay = true;
					this.isPlay = true;
					console.log('file url: ' + self.fileUrl);
					RECORD.play({
						url: self.fileUrl,
						success: function(ret) {
							console.log('播放完成');
							self.isPlay = false;
						},
						error: function(err) {
							self.isPlay = false;
							console.log('play error: ' + JSON.stringify(err));
						}
					});
					self.isPlay = true;
				}
			}
		},
		created: function() {
			var self = this;
			console.log('传递数据：' + JSON.stringify(api.pageParam.data));
			if(self.isEdit){
				self.file = api.pageParam.data.file;
				self.fileName = api.pageParam.data.fileName || api.pageParam.data.dataJson.filename;
				self.fileUrl = api.pageParam.data.fileUrl || api.pageParam.data.dataJson.filepath;

				var filesize = 0
				if(api.pageParam.data.dataJson.filesize){ //外勤签到
					filesize = api.pageParam.data.dataJson.filesize
				}else{
					filesize = api.pageParam.data.dataJson.attachsize
				}
			}	
			if (/^[fs://]/.test(self.fileUrl)) {
				self.isRecording = false;
				self.secondTime = api.pageParam.data.dataJson.voiceTime;
				self.speedTime = TIME.millisecondToDate(filesize);
			}
			if (self.isEdit) {
				self.isRecording = false;
				self.autoDownload(); // 自动下载
				self.secondTime = filesize;
				self.speedTime = TIME.millisecondToDate(filesize);
			}

			var btnLock = false;
			_g.addEventListener({ // 保存录音
				name: api.winName + '-save',
				success: function(ret) {
					if (self.fileName == '') {
						_g.toastMsg({
							msg: '请输入录音名称'
						});
						return;
					}
					if (!btnLock) {
						if (self.isEdit) {
							api.sendEvent({
								name: 'annex-edit',
								extra: {
									paramJson: {
										fileName: self.fileName,
										itemIndex: self.itemIndex,
										voiceTime: self.secondTime,
									}
								}
							});
							btnLock = true;
						} else {
							api.sendEvent({
								name: 'annex-upload',
								extra: {
									paramJson: {
										filePath: self.fileUrl,
										fileName: self.fileName,
										fileType: FILE.getTypeByPath(self.fileUrl),
										voiceTime: self.secondTime,
										itemIndex: BUSINESS.unknownToEmpty(self.itemIndex),
									}
								}
							});
							btnLock = true;
						}
					}
					setTimeout(function() {
						api.closeWin();
					}, 500);
				}
			});

			_g.addEventListener({ // 提示事件
				name: 'SHOW-FILE-LOADING',
				success: function(ret) {
					_g.showLoading({
						msg: '正在上传'
					});
				}
			});

			_g.addEventListener({
				name: 'HIDE-FILE-LOADING',
				success: function(ret) {
					api.hideProgress();
				}
			});
		}
	});
});
