define(function(require, exports, module) {

	var FILE = require('file');
	var MODULES = require('modules');
	var PHOTOBROWSER = require('photoBrowser');

	var vm = new Vue({
		el: '#vm',
		data: {
			file: api.pageParam.data.file,
			fileName: api.pageParam.data.fileName,
			fileUrl: api.pageParam.data.fileUrl,
			isEdit: api.pageParam.data.isEdit,
			itemIndex: api.pageParam.data.itemIndex, // 附件元素序号（编辑）
			isEdit: api.pageParam.data.isEdit, // 标示是否显示重新上传和确定按钮
			readOnly: api.pageParam.readOnly || false,
		},
		methods: {
			reSelectFile: function() { // 重新选择上传文件
				var self = this;
				MODULES.fileBrowser({
					success: function(ret) {
						if (ret.url !== '') {
							console.log('上传回调：' + JSON.stringify(ret));
							// 更新文件和文件名
							self.fileName = FILE.getFullNameByPath(ret.url);
							self.fileUrl = ret.url;
						}
					}
				});
			},
			unknownToEmpty: function(val){
				// 过滤null和undefined为空字符串
				if(val === null || val === undefined){
					val = '';
				}
				return val;
			},
			showDetail: function() { // 打开文件
				var self = this;
				if (self.isEdit) {
					_g.showLoading({
						msg: '正在下载'
					});
					var savePath = 'fs://download/' + self.file;
					FILE.download({  // 下载文件
						url: self.fileUrl,
						savePath: savePath,
						success: function(ret) {
							_g.hideProgress();
							_g.toastMsg({
								msg: '下载成功'
							});
							console.log('下载返回参数：' + JSON.stringify(ret));
							console.log('下载的文件地址' + savePath);
							FILE.open({
								path: savePath,
							});
						}
					});
				} else {
					FILE.open({ // 打开文件
						path: self.fileUrl
					});
				}
			}
		},
		created: function() {
			var self = this;
			console.log('传递参数：' + JSON.stringify(api.pageParam));
			self.fileName = api.pageParam.data.fileName
			self.fileUrl = api.pageParam.data.fileUrl;
			console.log('图片地址：' + self.fileUrl);
			if (self.isEdit) { // 是否为编辑
				self.file = api.pageParam.data.file;
			}

			var btnLock = false;
			_g.addEventListener({ // 保存文件
				name: api.winName + '-save',
				success: function(ret) {
					console.log(self.isEdit);
					if (self.fileName == '') {
						_g.toastMsg({
							msg: '请输入文件名称'
						});
						return;
					}
					if (self.isEdit) {
						api.sendEvent({
							name: 'annex-edit',
							extra: {
								paramJson: {
									fileName: self.fileName,
									itemIndex: self.itemIndex,
								}
							}
						});
						btnLock = true;
					} else {
						api.sendEvent({
							name: 'annex-upload',
							extra: {
								paramJson: {
									filePath: self.fileUrl,
									fileName: self.fileName,
									fileType: FILE.getTypeByPath(self.fileUrl),
									itemIndex: self.unknownToEmpty(self.itemIndex),
								}
							}
						});
						console.log(FILE.getTypeByPath(self.fileUrl));
						btnLock = true;
					}
					setTimeout(function() {
						api.closeWin()
					}, 500);
				}
			});

			_g.addEventListener({ // 提示事件
				name: 'SHOW-FILE-LOADING',
				success: function(ret) {
					_g.showLoading({
						title: '正在上传'
					});
				}
			});
			_g.addEventListener({
				name: 'HIDE-FILE-LOADING',
				success: function(ret) {
					_g.hideProgress();
				}
			});
		},
	});
});
