define(function(require, exports, module) {

	_g.showLoading();
	
	var INTERFACE = require('interface');
	var COMMAND = require('command');
	var TIME = require('time');
	var BUSINESS = require('business');


	var content = new Vue({
		el: '#dataList',
		data: {
			items: [],
			filterItems: {},
			type: api.pageParam.type
		},
		watch: {
			'items': function(){
				var self = this
				_.each(self.items, function(ele, index, list) {
					ele.amount = ele.totalamt || ele.amount || 0;
					ele.amountColor = 'tx-gray';
					var amount = (ele.amount).toString();
					if(amount.indexOf('-') > -1){
						ele.amountColor = 'tx-red';
					}
					ele.billId = ele.invoiceid || ele.csaleid || ele.returnid || ele.recievedid || ele.crecievedid || ele.preturnid || '';
				})
			}
		},
		methods: {
			init: function(opts) { // 初始化
				var self = this;
				COMMAND.init({
					url: INTERFACE.business[self.type]['list'].url,
					data: {
						'condition_txf': '',
						'filterItemRelation': '全部并且',
						'start': 0,
						'orderByField': 'm.billdate',
						'dir': 'DESC',
						'pageSize': 10
					},
					method: 'post',
					success: function(ret) {
						// _.each(ret.listData, function(ele, index, list) {
						// 	ele.amount = ele.totalamt || ele.amount || 0;
						// 	ele.amountColor = 'tx-gray';
						// 	var amount = (ele.amount).toString();
						// 	if(amount.indexOf('-') > -1){
						// 		ele.amountColor = 'tx-red';
						// 	}
						// 	ele.billId = ele.invoiceid || ele.csaleid || ele.returnid || ele.recievedid || ele.crecievedid || ele.preturnid || '';
						// })
						self.items = ret.listData;
						console.log(JSON.stringify(self.items))
					}
				});
			},
			onTapOpen: function(item) { // 打开详情
				var self = this;
				_g.openWin({
					name: self.type + '-edit',
					url: self.type + '-edit',
					pageParam: {
						type: self.type,
						billid: item.billId || item.orderid || item.sorderid
					}
				})
			},
			refresh: function() { // 刷新
				var self = this;
				api.sendEvent({ // 清空搜索框
					name: api.winName + '-search-clear'
				});
				COMMAND.refresh({
					modify: {
						'filterItemRelation': '全部并且'
					},
					success: function(ret) {
						// _.each(ret.listData, function(ele, index, list) {
						// 	ele.amount = ele.totalamt || ele.amount || 0;
						// 	ele.amountColor = 'tx-bla';
						// 	var amount = (ele.amount).toString();
						// 	if(amount.indexOf('-') > -1){
						// 		ele.amountColor = 'tx-red';
						// 	}
						// 	ele.billId = ele.invoiceid || ele.csaleid || ele.returnid || ele.recievedid || ele.crecievedid || ele.preturnid || '';
						// })
						self.items = ret.listData;
					}
				});
			}
		},
		created: function() {
			console.log(_g.j2s(api.pageParam));
			var self = this;
			self.init({});
		},
		mounted: function() {
			var self = this;
			_g.addEventListener({ // 搜索
				name: api.winName + '-search',
				success: function(ret) {
					_g.showLoading({
						title: '正在搜索'
					});
					var keyword = ret.value.keyword
					var filterItems = {
						'filterItemRelation': '全部或者'
					};
					var fieldid = {
						'sale-return': [70080, 70081, 70082, 70083, 70084, 70085, 70100, 70089],
						'pur-return': [70020, 70021, 70022, 70023, 70024, 70028, 70635, 70030],
						'pur-gain': [70000, 70001, 70002, 70003, 70005, 70634, 70006],
						'sale-del': [70039, 70040, 70042, 70043, 70044, 70036, 70041],
						'cash-sale': [70058, 70059, 70060, 70061, 70062, 70637, 70066, 70067, 70064],
						'cash-pur': [70245, 70246, 70247, 70248, 70249, 70250, 70252, 70253],
						'pur-order': [70322, 70323, 70324, 70325, 70326, 70328],
						'sale-order': [70303, 70304, 70305, 70306, 70307, 70309]
					};
					var fieldlabel = {
						'sale-return': ['单据编号', '仓库', '客户名称', '分支机构', '业务员', '联系人', '客户编码', '付款帐户'],
						'pur-return': ['单据编号', '供应商名称', '仓库', '业务员', '联系人', '收款账户', '分支机构', '供应商编码'],
						'pur-gain': ['单据编号', '供应商名称', '仓库', '业务员', '操作员', '分支机构', '供应商编码'],
						'sale-del': ['单据编号', '客户', '业务员', '联系人', '客户编码', '分支机构', '仓库'],
						'cash-sale': ['单据编号', '客户', '仓库', '业务员', '联系人', '分支机构', '收款方式', '付款账户', '客户编码'],
						'cash-pur': ['单据编号', '仓库', '操作员', '分支机构', '供应商名称', '供应商编码', '业务员', '付款账户'],
						'pur-order': ['单据编号', '操作员', '分支机构', '供应商名称', '供应商编码', '业务员'],
						'sale-order': ['单据编号', '操作员', '分支机构', '客户', '客户编码', '业务员']
					};

					var fieldtype = {
						'sale-return': ['ft_Str', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_Str', 'ft_ListStr', 'ft_ListStr'],
						'pur-return': ['ft_Str', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_Str'],
						'pur-gain': ['ft_Str', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_Str'],
						'sale-del': ['ft_Str', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr','ft_Str', 'ft_ListStr', 'ft_ListStr'],
						'cash-sale': ['ft_Str', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_Str'],
						'cash-pur': ['ft_Str', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr', 'ft_Str', 'ft_ListStr', 'ft_ListStr'],
						'pur-order': ['ft_Str', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr','ft_Str', 'ft_ListStr'],
						'sale-order': ['ft_Str', 'ft_ListStr', 'ft_ListStr', 'ft_ListStr','ft_Str', 'ft_ListStr']
					};
					if (keyword != '') {
						_.each(fieldid[self.type], function(ele, index, list) {
							filterItems['filterItems[' + index + '].displayvalue'] = keyword;
							filterItems['filterItems[' + index + '].fieldid'] = fieldid[self.type][index];
							filterItems['filterItems[' + index + '].fieldlabel'] = fieldlabel[self.type][index];
							filterItems['filterItems[' + index + '].fieldtype'] = fieldtype[self.type][index];
							filterItems['filterItems[' + index + '].itemno'] = index;
							filterItems['filterItems[' + index + '].operate'] = '包含';
							filterItems['filterItems[' + index + '].realvalue'] = keyword;
						})
					}
					self.filterItems = filterItems;
					COMMAND.search({
						searchJson: self.filterItems,
						success: function(ret) {
							self.items = ret.listData;
						}
					});
				}
			});

			_g.topLoading({ // 上拉加载
				success: function(ret) {
					COMMAND.next({
						success: function(ret) {
							self.items = _.union(self.items, ret.listData);
						}
					});
				}
			});

			_g.refresh({ // 下拉刷新 
				success: function(ret) {
					self.refresh();
				}
			});

			_g.addEventListener({
				name: 'bill-list-reload',
				success: function(ret) {
					self.refresh();
				}
			});

			var _tit = '供应商';
			var _tag = 'vendor';
			if (self.type == 'sale-return' || self.type == 'sale-del' || self.type == 'cash-sale' || self.type == 'sale-order') {
				_tit = '客户';
				_tag = 'businessTrader'
			}
			var filterData = { // 过滤参数
				filterName: 'selected-' + api.frameName,
				stage: {
					hasStage: true,
					startTime: TIME.getDates().sDate,
					endTime: TIME.getDates().eDate
				},
				listItem:[
					{
						type: 'select-win',
						title: _tit,
						tag: _tag,
						extraParams: {filter: '1=1'},
						selected: {
							value: '不限'
						}
					}
				]
			}
			_g.setLS('selected-' + api.frameName, filterData);


			_g.addEventListener({ // 打开过滤页面
				name: api.winName + '-filter',
				success: function(ret) {
					_g.openWin({ // 打开过滤页面
						name:'filter',
						url:'../Common/filter',
						pageParam: _g.getLS('selected-'+api.frameName)
					})
				}
			});

			_g.addEventListener({ // 监听进行过滤操作
				name: 'selected-' + api.frameName + '-filterAction',
				success: function(ret) {
		     	api.sendEvent({ // 清除关键字
						name: api.winName + '-search-clear',
					});
					var filterData = _g.getLS('selected-'+api.frameName);
					console.log(_g.j2s(filterData));

					var filters = {};
					var itemIndex = -1;
					var fieldid = {
						'sale-return': 70082,
						'pur-return': 70021,
						'pur-gain': 70001,
						'sale-del': 70040,
						'cash-sale': 70059,
						'cash-pur': 70249,
						'pur-order': 70325,
						'sale-order': 70306

					}
					_.each(filterData.listItem, function(ele, index, list) {
						ele.selected = ele.selected || '';
						if (ele.title == '客户' && ele.selected.value != '不限') {
							itemIndex += 1;
							var filterItems = {};
							filterItems['filterItems['+itemIndex+'].displayvalue']= ele.selected.shortname;
							filterItems['filterItems['+itemIndex+'].fieldid']= fieldid[self.type];
							filterItems['filterItems['+itemIndex+'].fieldlabel'] = ele.title + '名称';
							filterItems['filterItems['+itemIndex+'].fieldtype'] = 'ft_ListStr';
							filterItems['filterItems['+itemIndex+'].itemno']= itemIndex;
							filterItems['filterItems['+itemIndex+'].operate'] = '等于';
							filterItems['filterItems['+itemIndex+'].realvalue'] = ele.selected.shortname;
							$.extend(filters, filterItems);
						}
						if (ele.title == '供应商' && ele.selected.value != '不限') {
							itemIndex += 1;
							var filterItems = {};
							filterItems['filterItems['+itemIndex+'].displayvalue']= ele.selected.shortname;
							filterItems['filterItems['+itemIndex+'].fieldid']= fieldid[self.type];
							filterItems['filterItems['+itemIndex+'].fieldlabel'] = ele.title + '名称';
							filterItems['filterItems['+itemIndex+'].fieldtype'] = 'ft_ListStr';
							filterItems['filterItems['+itemIndex+'].itemno']= itemIndex;
							filterItems['filterItems['+itemIndex+'].operate'] = '等于';
							filterItems['filterItems['+itemIndex+'].realvalue'] = ele.selected.shortname;
							$.extend(filters, filterItems);
						}
					});

					filters.beginDate = filterData.stage.startTime; //开始时间
					filters.endDate = filterData.stage.endTime; //结束时间
					filters.filterItemRelation = '全部或者';

					COMMAND.filter({
						filterJson: filters,
						success: function(ret) {
							self.items = ret.listData;
						}
					});
				}
			});
		}
	});
});
