define(function(require, exports, module) {

	var COMMAND = require('command');
	var BUSINESS = require('business-erp');

	var vm = new Vue({
		el: '#vm',
		template: _g.getTemplate('Business/list-select-frame-v'),
		data: {
			eventName: '',
			type: api.pageParam.type,
			items: [],
			index: '',
			activeItem: {},
			hideItems: []
		},
		methods: {
			init: function() { // 初始化
				var self = this;
				self.eventName = api.pageParam.eventName;
				COMMAND.init({
					url: api.pageParam.url,
					data: api.pageParam.params,
					method: 'get',
					success: function(ret) {
						if (self.type == 'batchcode') {
							self.items = self.dealData(ret.resultData.batch);
						} else {
							if(self.type == 'qryTrader'){
								_.each(ret.listData, function(val, index){
									val.name = val.shortname
								})
							}
							self.items = self.dealData(ret.listData);
							if(self.type == 'billkindname'){
								_.each(self.hideItems, function(val, key){
									var index = _.findLastIndex(self.items, {
									  name: val
									});
									self.items.splice(index, 1)
								})
							}
						}
					}
				});
			},
			onTapChoose: function(item, index) { // 选中
				var self = this;
				_.each(self.items, function(ele, index, list) {
					ele.active = false;
				});
				item.active = true;
				self.activeItem = item;
				self.index = index;
			},
			dealData: function(items) { // 处理返回值
				return BUSINESS.addKeyValue({
					data: items,
					key: 'active',
					value: false
				});
			}
		},
		created: function() {
			var self = this;
			if(self.type == 'billkindname'){
				// 针对单据类型的一些选项进行隐藏
				api.sendEvent({
					name: 'Business-list',
					extra: {
						type: 'typeHideItem'
					}
				})
				_g.addEventListener({ 
					name: 'Business-getHideItem',
					success: function(ret) {
						self.hideItems = ret.value.items
						self.init();
					}
				});
			}else{
				self.init();
			}
		},
		mounted: function() {
			var self = this;
			_g.addEventListener({ // 搜索
				name: api.winName + '-search',
				success: function(ret) {
					var keyword = ret.value.keyword;
					COMMAND.search({
						searchJson: searchJson,
						success: function(ret) {
							if (self.type == 'batchcode') {
								self.items = self.dealData(ret.resultData.batch);
							} else {
								if(self.type == 'qryTrader'){
									_.each(ret.listData, function(val, index){
										val.name = val.shortname
									})
								}
								self.items = self.dealData(ret.listData);
							}
						}
					});
				}
			});
			
			_g.topLoading({ // 上拉加载
				success: function(ret) {
					COMMAND.next({
						success: function(ret) {
							if (self.type == 'batchcode') {
								self.items = _.union(self.items, self.dealData(ret.resultData.batch));
							} else {
								if(self.type == 'qryTrader'){
									_.each(ret.listData, function(val, index){
										val.name = val.shortname
									})
								}
								self.items = _.union(self.items, self.dealData(ret.listData));
							}
						}
					});
				}
			});

			_g.refresh({ // 下拉刷新
				success: function(ret) {
					COMMAND.refresh({
						success: function(ret) {
							if (self.type == 'batchcode') {
								self.items = self.dealData(ret.resultData.batch);
							} else {
								if(self.type == 'qryTrader'){
									_.each(ret.listData, function(val, index){
										val.name = val.shortname
									})
								}
								self.items = self.dealData(ret.listData);
							}
						}
					});
				}
			});

			_g.addEventListener({
				name: api.winName + '-right',
				success: function(ret) {
					if(self.type != 'qryCcontcat'){
						if (self.index === '') {
							_g.toastMsg({
								msg: '请选择一个' + api.pageParam.title
							});
							return;
						}
					}
					api.pageParam.data = self.activeItem;
					api.pageParam.index = self.index;
					api.sendEvent({
						name: self.eventName,
						extra: api.pageParam
					});
					setTimeout(function(){
						api.closeWin();
					}, 800);
				}
			})
		}
	});
});
