define(function(require, exports, module) {
	var INTERFACE = require('interface');
	var HTTP = require('http');
	var TIME = require('time');
	var BUSINESS = require('business-erp');
	var _C = require('components');

	var vm = new Vue({
		el: '#vm',
		template: _g.getTemplate('Business/sale-chance-detail-frame-v'),
		components: {
			'btns-layer': _C.getBtnsLayer({
			    'height': api.frameHeight
			})
		},
		data: {
			btns: [],
			type: 'chance', // （销售机会）单据类型
			mode: api.pageParam.mode || 'add', // 单据模式（新增: add, 编辑: edit）
			index: api.pageParam.index || 0, // 单据数组序号（列表更新）
			isDetail: api.pageParam.mode == 'edit' ? true : false, // 是否为详情
			canEditDateCode: true,  // 是否能编辑日期及编号
			bill: {
				id: api.pageParam.id, // 单据id
				modId: BUSINESS.param['chance'].modId,
				master: {
					traderid: null,
					tradername: '',
					contactname: '',
					contactid: null,
					amount: 0,
					billdate: '',
					enddate: '',
					billcode: '',
					chancetypename: '',
					status: '',
					empname: '',
					empid: ''
				}, // 主单据
				goods: [], // 商品明细
				delGoods: [], // 删除的商品明细数组
				detail1IdArr: [], // 新增或编辑过的商品明细id数组
				openGoodsIndex: 0, // 记录打开的商品序号
			},
			judgment: { // 判定值
				isCheck: false, // 是否已审核
				canEditPrice: true // 是否能否编辑货品单价
			},
			permissions: { // 权限
				amount: false, // 是否能编辑金额
			},
			annex: { // 附件
				len: 0, // 附件数量
				dataJson: [], // 附件数据
			},
			isEditer: true, // 是否为可编辑模式
			check: { // 审批流程
				isShow: false, // 是否显示
			},
			process: { // 阶段进程
				isShow: false, // 是否显示
				isList: true, // 是否展开列表
				data: [],
			},
			follow: { // 跟进记录
				isShow: false, // 是否显示
			},
			showDelBtn: false // 是否显示删除按钮
		},
		watch: {
			'bill.master.possibility': function(val, oldVal) {
				var self = this;
				if (val < 0) {
					_g.toastMsg({
						msg: '可能性不能小于0'
					});
					self.bill.master.possibility = oldVal;
				} else if (val > 100) {
					_g.toastMsg({
						msg: '可能性不能大于100'
					});
					self.bill.master.possibility = oldVal;
				}
			}
		},
		methods: {
			openTapGetDate: function(billdate) { //选择日期
				var self = this
				if(self.canEditDateCode){
					_g.openPicker({
						date: billdate,
						success: function(ret){
							self.bill.master.billdate =  ret.year + '-' + ret.month + '-' + ret.day
						}
					})
				}
			},
			showBtn: function(opts) { // 显示删除按钮
				var self = this;
				self.btns.push({
					title: opts.title,
					icon: opts.icon
				});
			},
			delBtn: function(opts) { // 删除按钮
				var self = this;
				var tempBtns = _g.s2j(_g.j2s(self.btns));
				_.each(tempBtns, function(ele, index, list) {
					if (opts.title == ele.title) {
						self.btns.splice(index, 1);
						return;
					}
				});
			},
			updateBtns: function() { // 更新按钮
				var self = this;
				api.sendEvent({
					name: api.winName + '-btn-more-update',
					extra: {
						btns: self.btns
					}
				});
			},
			init: function() { // 初始化
				var self = this;
				if (self.mode == 'add') {
					self.initAdd();
					self.changeEvent(); // 初始化页面改变事件
				} else {
					self.initEdit();
					self.getChanceStatus(); // 获取阶段进程
				}
				self.initEvent(); // 初始化(事件)
			},
			initAdd: function() { // 初始化(新增)
				var self = this;
				HTTP.ajax({
					url: INTERFACE.business[self.type][self.mode].url,
					data: {},
					success: function(ret) {
						self.addSaveBtn(); // 添加保存按钮
						self.updateBtns();
						ret.master.contactname = ''
						ret.master.contactid = null
						self.bill.master = ret.master; //主单据
						self.canEditDateCode = ret.resultData.canEditDateCode;
//						self.bill.master.moneyname = '人民币'; // 币种
//						self.bill.master.moneycode = '￥';
//						self.bill.master.moneyid = 0; // 币种id
						self.bill.master.enddate = TIME.getDates().eDate;
						//self.bill.master.contactname = ''
						//self.bill.master.contactid = null
						self.bill.master.billdate = self.bill.master.startdate = self.bill.master.enddate = TIME.getDates().eDate;

						self.judgment.canEditPrice = ret.resultData.canEditSPrice; // 是否能否编辑货品单价
					}
				});
			},
			initEdit: function(opts) { // 初始化(编辑)
				var self = this;
				HTTP.ajax({
					url: INTERFACE.business[self.type][self.mode].url,
					data: {
						billId: self.bill.id,
						modId: BUSINESS.param[self.type].modId
					},
					success: function(ret) {
						$.extend(self.bill.master, ret.master); //主单据
						self.bill.master.contactname = ret.master.contactor; // 联系人
						self.bill.backup = ret.master; // 备份主单据
						self.canEditDateCode = ret.resultData.canEditDateCode

						// 初始化按钮
						var billstate = ret.master.billstate;
						if (billstate == 0 || billstate == 1) {
							self.showBtn({
								title: '微信分享',
								icon: 'wx'
							});
							self.showBtn({
								title: 'QQ分享',
								icon: 'qq'
							});
							self.showBtn({
								title: '打印',
								icon: 'print'
							});
							if (billstate == 0) {
								self.addSaveBtn(); // 添加保存按钮
								self.showBtn({
									title: '删除',
									icon: 'del'
								});
								self.showDelBtn = true;
//								self.showBtn({
//									title: '审核'
//								});
							} else {
//								self.showBtn({
//									title: '反审核'
//								});
							}
						} else {
							api.sendEvent({
								name: api.winName + '-btns-update',
								extra: {
									btns: []
								}
							})
						}

						// 设置单据明细
						var rdetail1 = ret.detail1;
						if (Array.isArray(rdetail1) && rdetail1.length > 0) {
							_.each(rdetail1, function(ele, index, list) {
								ele.moneycode = ret.master.moneycode;
								ele.goodMode  = ele.oldgoodMode = 'old';
							});
						}
						self.bill.goods = rdetail1;
						_g.setLS('productJson', { // 缓存货品明细
							list: rdetail1 || [],
							amount: ret.master.amount
						});
						self.updateBtns(); // 更新按钮

						self.judgment.canEditPrice = ret.resultData.canEditSPrice; // 是否能否编辑货品单价

						if (ret.master.billstate == 0) {
							self.isEditer = true; // 设置不可编辑
							self.judgment.isCheck = false;
						} else { // 已审批后不可编辑
							self.isEditer = false; // 设置不可编辑
							self.judgment.isCheck = true;
						}

						BUSINESS.getAnnex({ // 获取附件数据
							data: {
								id: self.bill.id,
								modId: BUSINESS.param[self.type].modId,
							},
							success: function(ret) {
								self.annex.len = ret.data.detail1.length || 0; // 获取附件数量
								self.annex.dataJson = ret.data.detail1; // 获取附件数据
							}
						});

						self.follow.isShow = true; // 显示跟进记录
						self.changeEvent(); // 初始化页面改变事件

						if (api.pageParam.isDetail) { // 处理详情不可编辑
							for(var key in self.edit) {
								self.edit[key] = false;
							}
							self.showDelBtn = false;
							api.sendEvent({
								name: api.winName + '-btns-update',
								extra: {
									btns: []
								}
							})
							self.judgment.isCheck = true;
							self.isEditer = false;
						}
					},
					error: function(err) {
						api.hideProgress();
						_g.toastMsg({
							msg: err.msg
						});
					}
				});
			},
			initEvent: function() { // 初始化(事件)
				var self = this;
				_g.addEventListener({ // 点击“更多”按钮
					name: api.winName + '-more',
					success: function(ret) {
						api.sendEvent({
							name: api.winName + '-btns-layer',
							extra: {
								type: 'change'
							}
						})
					}
				});
				_g.addEventListener({ // 操作按钮事件
					name: api.winName + '-btns-layer-selected', //api.winName + '-btns-layer-click',
					success: function(ret) {
						var title = ret.value.selected.title;
						console.log('detail:'+JSON.stringify(self.bill))
						BUSINESS.setData({
							type: self.type, // 业务类型
							mode: self.mode, // 模式
							bill: self.bill, // 数据
							index: self.index
						});
						switch (title) {
							case '删除':
								BUSINESS.del();
								break;
							case '保存':
								if (!BUSINESS.verify()) { // 表单验证
									return;
								}
								BUSINESS.save({
									success: function(ret) {
										console.log('保存');
									}
								});
								break;
							case '打印':
								BUSINESS.print({});
							break;
							case '微信分享':
								BUSINESS.share({
									type: 'wx',
									success: function(ret) {
										console.log('微信分享');
									}
								});
								break;
							case 'QQ分享':
								BUSINESS.share({
									type: 'qq'
								});
								break;
							case '审核':
								BUSINESS.approval({
									tips: '审核'
								});
								break;
							case '反审核':
								BUSINESS.unapproval();
								break;
							default:
						}
					}
				});

				_g.addEventListener({ // 基础资料返回参数事件
					name: api.winName + '-get-winselected', // api.winName + '-list-select',
					success: function(ret) {
						console.log(_g.j2s(ret));
						var tag = ret.value.tag; // 基础资料类型
						var data = ret.value.selectedData[0]; // 选择的资料数据
						switch (tag) {
							case 'qryTrader': // 客户
								Vue.set(self.bill.master, 'traderid', data.clientid);
								Vue.set(self.bill.master, 'tradername', data.shortname);
								// self.bill.master.traderid = data.clientid;
								// self.bill.master.tradername = data.shortname;
								break;
								// 联系人
							case 'qryCcontcat':
								console.log('master:'+JSON.stringify(self.bill.master))
								// self.bill.master.contactid = data.id || '';
								//self.bill.master.contactname = data.name;
								Vue.set(self.bill.master, 'contactid', data.id || '')
								Vue.set(self.bill.master, 'contactname', data.name || '')
								break;
							case 'qryChanceState': // 阶段
								Vue.set(self.bill.master, 'status', data.id || '')
								Vue.set(self.bill.master, 'chancetypename', data.name || '')
								// self.bill.master.status = data.id;
								// self.bill.master.chancetypename = data.name;
								break;
							case 'qryEmploy': // 业务员
								// self.bill.master.empid = data.id;
								// self.bill.master.empname = data.name;
								Vue.set(self.bill.master, 'empid', data.id || '')
								Vue.set(self.bill.master, 'empname', data.name || '')
							default:
						}
					}
				});

				_g.addEventListener({ // 商品操作事件
					name: 'goods-update',
					success: function(ret) {
						if(ret.value.type == 'chance'){
							console.log(ret.value.goodMode);
							var mode = ret.value.mode;
							var goodMode = ret.value.goodMode; // 商品模式(old:单据本身商品, add:新增, edit:编辑过, del:已删除)
							var goods = ret.value.goods; // 商品数据
							//alert('this:'+JSON.stringify(ret.value))
							switch(mode) {
								case 'save':
									if (goodMode == 'new' || goodMode == 'add') {
										_.each(goods, function(ele, index, list){
											ele.oldgoodMode = ele.goodMode = 'add';
											ele.isSelected = true;
											ele.unitqty = ele.qty;
											ele.unitquantity = ele.quantity;
											ele.price = parseFloat(ele.price).toFixed(2);
											self.bill.goods.unshift(ele); // 更新列表
										})
										console.log(JSON.stringify(self.bill.goods))
									} else { // add 、edit、old
										if(goodMode == 'old'){ // 标识原有商品已被编辑状态
											goods.oldgoodMode == goods.goodMode
											goods.price = parseFloat(goods.price).toFixed(2)
											goods.goodMode = 'edit';
										}
										goods.unitqty = goods.qty;
										goods.unitquantity = goods.quantity;
										Vue.set(self.bill.goods, self.bill.openGoodsIndex, goods); // 更新所编辑商品的数据
									}
									break;
								case 'del':
									if (goodMode == 'edit' || goodMode == 'old') { // 如果是本来有的商品才需要提交到被删除的商品列表
										self.bill.delGoods.push(self.bill.goods[self.bill.openGoodsIndex]);
									}
									self.bill.goods.splice(self.bill.openGoodsIndex, 1); // 移除数据
									break;
							}
			    		// 更新合计
			    		var amount = 0;
							_.each(self.bill.goods, function(ele, index, list){
								amount += Number(ele.amount);
							});
						// 修复：选择多条货品后明细合计金额有时显示不对 by oz
						self.bill.master.amount = parseFloat(amount).toFixed(2);
							_g.setLS('productJson', { // 缓存商品明细
								list: self.bill.goods,
								amount: self.bill.master.amount
							});
						}
					}
				});

				_g.addEventListener({ // 附件统计数量统计事件
					name:'annex-num',
					success: function(ret) {
						if (ret.value.type == 'add') {
							self.annex.len += 1;
						} else {
							self.annex.len -= 1;
						}
					}
				});
			},
			onTapDel: function() { // 删除
				api.sendEvent({
					name: api.winName + '-btns-layer-click',
					extra: {
						btn: {
							title: '删除'
						}
					}
				})
			},
			addSaveBtn: function() { // 添加保存按钮
				var self = this;
				self.showBtn({
					title: '保存',
					icon: 'save'
				});
				api.sendEvent({
					name: api.winName + '-btns-add',
					extra: {
						start: 0,
						btn: {
							event: api.winName + '-save',
							icon: 'save'
						}
					}
				})
			},
			changeEvent: function() { // 页面改变事件
				var self = this;
				self.$watch('bill.master.tradername', function(val, oldVal) { // 重选客户后清除已选联系人
					self.bill.master.contactid = '';
					self.bill.master.contactname = '';
				});
			},
			getChanceStatus: function() { // 获取阶段进程
				var self = this;
				HTTP.ajax({
					url: URLANNEX + '/ncrm/chance/chanceEdit!doGetChanceStatus.action',
					data: {
						billId: self.bill.id,
						modId: BUSINESS.param[self.type].modId
					},
					success: function(ret) {
						var processData = ret.resultData.root || [];
						if (processData.length > 0) {
							self.process.isShow = true;
							self.process.data = processData;
						}
					},
					error: function(err) {
						_g.toastMsg({
							msg: err.msg
						});
					}
				});
			},
			onTapGetDate: function(key) { // 日期选择
				var self = this;
				TIME.getPickerDates(self.bill.master[key], function(chooseDate) {
					Vue.set(self.bill.master, key, chooseDate)
				});
			},
			onTapOpenBase: function(key) { // 打开选择基础资料
				console.log(key)
				var self = this;
				var param = {};
				var traderid = self.bill.master.traderid || '';
				if (key == 'qryCcontcat' && traderid == '') {
					_g.toastMsg({
						msg: '请先选择客户!'
					});
					return;
				}
				switch(key){
					case 'qryTrader':  //客户
						param.title = '客户';
						param.tag = 'qryTrader';
						param.showName = ['shortname'];
						param.extraParams = {
							filter: "CLOSED='F' and phoneapply='T'",
							viewname: 'client_ds'
						};
					break;
					case 'qryCcontcat':  //联系人
						param.title = '联系人';
						param.tag = 'qryCcontcat';
						param.showName = ['name'];
						param.extraParams = {
							filter: 'clientid=' + traderid + ' and closed=0'
						}
					break;
					case 'qryChanceState':  //阶段
						param.title = '阶段';
						param.tag = 'qryChanceState';
						param.showName = ['name'];
						param.extraParams = {
							filter: "(1=1) and (name like '%%')"
						}
					break;
					case 'qryEmploy':  //业务员
						param.title = '业务员';
						param.url = URLANNEX + '/crmlookupdm/crmlookupdata.action';
						param.tag = 'qryEmploy';
						param.showName = ['name'];
						param.extraParams = {modId: 150};
					break;
				}
				_g.openWin({
					name: 'list-select',
					url: '../Common/list-select',
					pageParam: {
						isMultiSelect: false,
						title: param.title,
						tag: param.tag,
						frameName: api.winName,
						showName: param.showName,
						hasSearch: false,
						filter: param.filter,
						extraParams: param.extraParams
					}
				});

				// return;

				// var baseData = {};
				// if (key == 'qryCcontcat') {
					
				// 	baseData = BUSINESS.interface.base[key]({
				// 		traderid: traderid,
				// 		modId: BUSINESS.param[self.type].modId
				// 	});
				// } else {
				// 	baseData = BUSINESS.interface.base[key]({
				// 		modId: BUSINESS.param[self.type].modId
				// 	});
				// 	if(key == 'qryTrader'){
				// 		baseData.param = $.extend(baseData.param, {
				// 			filter: "CLOSED='F' and phoneapply='T'",
				// 			viewname: 'client_ds'
				// 		});
				// 	}
				// }
				// _g.openWin({
				// 	name: 'list-select',
				// 	url: './list-select',
				// 	pageParam: {
				// 		eventName: api.winName + '-list-select',
				// 		billType: self.type,
				// 		type: key,
				// 		title: baseData.title,
				// 		url: baseData.url,
				// 		params: baseData.param
				// 	}
				// });
			},
			onTapChooseGoods: function() { // 选择商品
				
				var self = this;
				//alert(self.type)
				var store_billData = {
		          'traderID': self.bill.master.traderid || 0,//客户或/供应商id
		          'noteType': 3, //发票类型为“收据”是1，其他0
		          'storeID': -1//仓库id
		        }
		        $api.setStorage('store_billData', store_billData);

		  		//_g.openWin({
				// 	name: 'pro_choose',
				// 	url: api.wgtRootDir + '/html/oldBusiness/pro_choose',
				// 	pageParam: {
				// 		type: self.type, // 单据类型
				// 		parWin: api.winName,
				// 		parFrame: api.frameName,
				// 		act: 'add' // 是否能够编辑
				// 	}
				// });
				_g.openWin({
					name: 'pro-choose',
					url: 'pro-choose',
					pageParam: {
						type: self.type, // 单据类型
						parWin: api.winName,
						parFrame: api.frameName,
						act: 'add' // 是否能够编辑
					}
				});
			},
			onTapOpenGoods: function(item, index) { // 打开商品详情
				var self = this;
				//alert(self.type)
				self.bill.openGoodsIndex  = index; //记录打开的商品序号
				var goodMode = item.goodMode || ''; // 货品明细状态(old:单据本身货品, add:新增, edit:编辑过, del:已删除)
				_g.setLS('productItem', item);
				
				var store_billData = {
          'traderID': self.bill.master.traderid || 0,//客户或/供应商id
          'noteType': 3, //发票类型为“收据”是1，其他0
          'storeID': -1//仓库id
        }
        $api.setStorage('store_billData', store_billData);
        _g.openWin({
					name: 'pro_choose',
					url: api.wgtRootDir + '/html/oldBusiness/pro_edit',
					pageParam: {
						type: self.type, // 单据类型
						parWin: api.winName,
						parFrame: api.frameName,
						goodMode: goodMode, // 货品明细状态(old:单据本身货品, add:新增, edit:编辑过, del:已删除)
						data: JSON.stringify(item),
						act: 'edit' // 是否能够编辑
					}
				});
//				_g.openWin({
//					name: 'product-detail',
//					url: 'product-detail-erp',
//					pageParam: {
//						type: self.type, // 单据类型
//						mode: self.mode, // 单据模式
//						parWin: api.winName,
//						parFrame: api.frameName,
//						isEditer: self.isEditer, // 是否能够编辑
//						index: index
//					}
//				});
			},
			onTapOpenAnnex: function() { // 打开附件
				var self = this;
				_g.openWin({
					name: 'annex',
					url: '../Annex/annex',
					pageParam: {
						paramJson: {
							readOnly: !self.isEditer,
							isDetail: self.mode == 'edit' ? true : false, // 单据是否为详情情况
							param: {
								id: self.bill.id, // 单据id
								modId: BUSINESS.param[self.type].modId, // 业务类型modId
							},
							dataJson: self.annex.dataJson, // 附件数据
						}
					}
				});
			},
			onTapOpenProcess: function() { // 阶段进程列表展开/收起
				var self = this;
				self.process.isList = !self.process.isList;
			},
			onTapOpenFollow: function() { // 打开跟进记录（获取客户跟进列表）
				var self = this;
				_g.openWin({
					name: 'follow',
					url: '../Index/follow',
					pageParam: {
						referbillid: self.bill.id, // 单据id
						title: '客户跟进记录',
						from: 'bussiness',
						bparam: {
							dsbilltype: { // 业务类型
								id: BUSINESS.param[self.type].modId,
								name: BUSINESS.param[self.type].title,
								code: BUSINESS.param[self.type].code
							},
							followBill: { // 跟进单据
								id: self.bill.master.id,
								name: self.bill.master.name,
								code: self.bill.master.code
							}
						}
					}
				});
			}
		},
		created: function() {
			console.log(_g.j2s(api.pageParam));
			var self = this;
			self.init();
		},
		mounted: function() {
		}
	});
});
