define(function(require, exports, module) {

	_g.showLoading();
	
	var INTERFACE = require('interface');
	var COMMAND = require('command');
	var TIME = require('time');
	var BUSINESS = require('business');

	var content = new Vue({
		el: '#content',
		template: _g.getTemplate('Business/sale-chance-frame-v'),
		data: {
			items: []
		},
		methods: {
			init: function(opts) { // 初始化
				var self = this;
				COMMAND.init({
					url: INTERFACE.business['chance']['list'].url,
					data: {
						modId: BUSINESS.param['chance'].modId,
						searchKey: opts.searchKey
					},
					method: 'post',
					success: function(ret) {
						self.items = ret.resultData.ListData;
					}
				});
			},
			onTapOpen: function(item, index) { // 打开详情
				_g.openWin({
					name: 'sale-chance-detail',
					url: 'sale-chance-detail',
					pageParam: {
						mode: 'edit',
						id: item.billid,
						index: index,
						item: item
					}
				})
			},
			refresh: function() { // 刷新
				var self = this;
				api.sendEvent({ // 清空搜索框
					name: api.winName + '-search-clear'
				});
				COMMAND.refresh({
					clear: true,
					success: function(ret) {
						self.items = ret.resultData.ListData;
					}
				});
			}
		},
		created: function() {
			console.log(_g.j2s(api.pageParam));
			var self = this;
			if(api.pageParam.keyword && api.pageParam.keyword != '') {
				//1.往搜索框里加keyword
				api.sendEvent({
					name: api.winName + '-get-keyword',
					extra: {
						keyword: api.pageParam.keyword
					}
				})
				//2.请求数据
				self.init({searchKey: api.pageParam.keyword});
			}else {
				self.init({});
			}
		},
		mounted: function() {
			var self = this;
			_g.addEventListener({ // 搜索
				name: api.winName + '-search',
				success: function(ret) {
					_g.showLoading({
						title: '正在搜索'
					});
					var keyword = ret.value.keyword
					COMMAND.search({
						searchJson: {
							searchKey: keyword
						},
						success: function(ret) {
							self.items = ret.resultData.ListData;
						}
					});
				}
			});

			_g.topLoading({ // 上拉加载
				success: function(ret) {
					COMMAND.next({
						success: function(ret) {
							self.items = _.union(self.items, ret.resultData.ListData);
						}
					});
				}
			});

			_g.refresh({ // 下拉刷新
				success: function(ret) {
					self.refresh();
				}
			});

			_g.addEventListener({
				name: 'bill-list-reload',
				success: function(ret) {
					self.refresh();
				}
			});

			var filterData = { // 过滤参数
				isReportOrProvider: true,
				filterName: 'selected-' + api.frameName,
				stage: {
					hasStage: true,
					startTime: TIME.getDates().sDate,
					endTime: TIME.getDates().eDate
				},
				listItem:[
					{
						type:'input',
						title: '单号'
					},
					{
						type:'input',
						title: '机会名称'
					},
					{
						type: 'select-win',
						title: '客户',
						tag: 'businessTrader',
						extraParams: {modId: 150},
						selected: {
							value: '不限'
						}
					},
					{
						type:'select-win',
						title: '阶段',
						tag: 'qryChanceState',
						selected: {
							value: '不限'
						}
					},
					{
						type:'select-win',
						title: '制单人',
						tag: 'qryOperator',
						selected: {
							value: '不限'
						}
					}
				]
			}
			_g.setLS('selected-' + api.frameName, filterData);

			_g.addEventListener({ // 打开过滤页面
				name: api.winName + '-filter',
				success: function(ret) {
					_g.openWin({ // 打开过滤页面
						name:'filter',
						url:'../Common/filter',
						pageParam: _g.getLS('selected-'+api.frameName)
					})
				}
			});

			_g.addEventListener({ // 监听进行过滤操作
				name: 'selected-' + api.frameName + '-filterAction',
				success: function(ret) {
		     	api.sendEvent({ // 清除关键字
						name: api.winName + '-search-clear',
					});
					var filterData = _g.getLS('selected-'+api.frameName);
					console.log(_g.j2s(filterData));

					var filters = {};
					var itemIndex = -1;
					_.each(filterData.listItem, function(ele, index, list) {
						ele.selected = ele.selected || '';
						if (ele.title == '单号' && ele.selected !== '') {
							itemIndex += 1;
							var filterItems = {};
							filterItems['filterItems['+itemIndex+'].fieldType']= 'ft_Str';
							filterItems['filterItems['+itemIndex+'].id'] = 1;
							filterItems['filterItems['+itemIndex+'].index'] = '';
							filterItems['filterItems['+itemIndex+'].name']= '单号';
							filterItems['filterItems['+itemIndex+'].operatertitle'] = '等于';
							filterItems['filterItems['+itemIndex+'].value'] = ele.selected;
							$.extend(filters, filterItems);
							filters.filterisOR = 'false';
						}
						if (ele.title == '机会名称' && ele.selected !== '') {
							itemIndex += 1;
							var filterItems = {};
							filterItems['filterItems['+itemIndex+'].fieldType']= 'ft_Str';
							filterItems['filterItems['+itemIndex+'].id'] = 2;
							filterItems['filterItems['+itemIndex+'].index'] = '';
							filterItems['filterItems['+itemIndex+'].name']= '机会名称';
							filterItems['filterItems['+itemIndex+'].operatertitle'] = '等于';
							filterItems['filterItems['+itemIndex+'].value'] = ele.selected;
							$.extend(filters, filterItems);
							filters.filterisOR = 'false';
						}
						if (ele.title == '客户' && ele.selected.value != '不限') {
							itemIndex += 1;
							var filterItems = {};
							filterItems['filterItems['+itemIndex+'].fieldType']= 'ft_ListStr';
							filterItems['filterItems['+itemIndex+'].id'] = 3;
							filterItems['filterItems['+itemIndex+'].index'] = '03';
							filterItems['filterItems['+itemIndex+'].name']= '客户';
							filterItems['filterItems['+itemIndex+'].operatertitle'] = '等于';
							filterItems['filterItems['+itemIndex+'].value'] = ele.selected.shortname;
							$.extend(filters, filterItems);
							filters.filterisOR = 'false';
						}
						if (ele.title == '阶段' && ele.selected.value != '不限') {
							itemIndex += 1;
							var filterItems = {};
							filterItems['filterItems['+itemIndex+'].fieldType']= 'ft_ListStr';
							filterItems['filterItems['+itemIndex+'].id'] = 5;
							filterItems['filterItems['+itemIndex+'].name']= '阶段';
							filterItems['filterItems['+itemIndex+'].operatertitle'] = '等于';
							filterItems['filterItems['+itemIndex+'].value'] = ele.selected.name;
							$.extend(filters, filterItems);
							filters.filterisOR = 'false';
						}
						if (ele.title == '制单人' && ele.selected.value != '不限') {
							itemIndex += 1;
							var filterItems = {};
							filterItems['filterItems['+itemIndex+'].fieldType']= 'ft_ListStr';
							filterItems['filterItems['+itemIndex+'].id'] = 10;
							filterItems['filterItems['+itemIndex+'].index'] = '02';
							filterItems['filterItems['+itemIndex+'].name']= '制单人';
							filterItems['filterItems['+itemIndex+'].operatertitle'] = '等于';
							filterItems['filterItems['+itemIndex+'].value'] = ele.selected.name;
							$.extend(filters, filterItems);
							filters.filterisOR = 'false';
						}
					});

					filters.startdate = filterData.stage.startTime; //开始时间
					filters.enddate = filterData.stage.endTime; //结束时间
					filters.limit = 10000;
					filters.modId = 150;

					COMMAND.filter({
						filterJson: filters,
						success: function(ret) {
							self.items = ret.resultData.ListData;
						}
					});
				}
			});
		}
	});
});
