define(function(require, exports, module) {

	var INTERFACE = require('interface');
	var HTTP = require('http');
	var TIME = require('time');
	var BUSINESS = require('business-erp');
	var _C = require('components');

	var vm = new Vue({
		el: '#vm',
		template: _g.getTemplate('Business/sale-price-detail-frame-v'),
		components: {
			'btns-layer': _C.getBtnsLayer({
			    'height': api.frameHeight
			})
		},
		data: {
			btns: [],
			type: 'price', // （销售报价）单据类型
			mode: api.pageParam.mode || 'add', // 单据模式（新增: add, 编辑: edit）
			index: api.pageParam.index || 0, // 单据数组序号（用于列表更新）
			canEditDateCode: true,  // 是否能编辑日期及编号
			bill: {
				id: api.pageParam.id, // 单据id
				master: {}, // 主单据
				goods: [], // 货品明细
				delGoods: [], // 删除的货品明细数组
				detail1IdArr: [], // 新增或编辑过的货品明细id数组
			},
			judgment: { // 判定值
				isCheck: false, // 是否已审核
				canEditPrice: true // 是否能否编辑货品单价
			},
			edit: {
				tradername: false
			},
			annex: { // 附件
				len: 0, // 附件数量
				dataJson: [], // 附件数据
			},
			isEditer: true, // 是否为可编辑模式
			follow: { // 跟进记录
				isShow: false, // 是否显示
			},
			check: { // 审批流程
				isShow: false, // 是否显示
			},
			showDelBtn: false // 是否显示删除按钮
		},
		methods: {
			openTapGetDate: function(billdate) { //选择日期
				var self = this
				if(self.canEditDateCode){
					_g.openPicker({
						date: billdate,
						success: function(ret){
							self.bill.master.billdate =  ret.year + '-' + ret.month + '-' + ret.day
						}
					})
				}
			},
			showBtn: function(opts) { // 显示删除按钮
				var self = this;
				self.btns.push({
					title: opts.title,
					icon: opts.icon
				});
			},
			delBtn: function(opts) { // 删除按钮
				var self = this;
				var tempBtns = _g.s2j(_g.j2s(self.btns));
				_.each(tempBtns, function(ele, index, list) {
					if (opts.title == ele.title) {
						self.btns.splice(index, 1);
						return;
					}
				});
			},
			updateBtns: function() { // 更新按钮
				var self = this;
				api.sendEvent({
					name: api.winName + '-btn-more-update',
					extra: {
						btns: self.btns
					}
				});
			},
			init: function() { // 初始化
				var self = this;
				if (self.mode == 'add') {
					self.initAdd();
					self.changeEvent(); // 初始化页面改变事件
				} else {
					self.initEdit();
				}
				self.initEvent(); // 初始化(事件)
			},
			initAdd: function() { // 初始化(新增)
				var self = this;
				HTTP.ajax({
					url: INTERFACE.business[self.type][self.mode].url,
					data: {},
					success: function(ret) {
						self.addSaveBtn(); // 添加保存按钮
						self.updateBtns();
						self.canEditDateCode = ret.resultData.canEditDateCode;
						
						self.bill.master = ret.master; //主单据
						self.bill.master.billdate = self.bill.master.startdate = self.bill.master.enddate = TIME.getDates().eDate;

						self.judgment.canEditPrice = ret.resultData.canEditSPrice; // 是否能否编辑货品单价
						self.edit.tradername = true;
					}
				});
			},
			getproOfchance: function(chance, callback){
				//拿到相关机会信息，来获取对应的商品
				_g.showLoading({
					title: '正在加载'
				});
				var self = this;
				HTTP.ajax({
					url: URLANNEX + '/ncrm/ssaleprice/ssalepriceselectChance!dogetDetailData.action',
					data: {
						moneyid: 0,
						traderid: self.bill.master.traderid,
						billId: chance.billid //相关机会
					},
					success: function(ret) {
						api.hideProgress()
						if(ret.detaillist && ret.detaillist.length != 0){
							_.each(ret.detaillist, function(val, key){
								val.referbilltype = 150
								val.referbillid = chance.billid
								val.referitemno  = val.itemno
								val.quantity  = val.unitquantity * val.unitrate
								val.unit = val.unitname
								val.unitqty = val.unitquantity
								val.goodMode = 'add'
							})
							callback(ret.detaillist)
						}else {
							callback([])
						}
						
					},
					error: function(){
						api.hideProgress()
						_g.toastMsg({
							msg: err.msg
						});
					}
				})
			},
			initEdit: function() { // 初始化(详情)
				var self = this;
				HTTP.ajax({
					url: INTERFACE.business[self.type][self.mode].url,
					data: {
						billId: self.bill.id,
						modId: BUSINESS.param[self.type].modId
					},
					success: function(ret) {
						self.bill.master = ret.master; //主单据
						self.bill.backup = ret.master; // 备份主单据
						self.canEditDateCode = ret.resultData.canEditDateCode
						// 初始化按钮
						var billstate = ret.master.billstate;
						if (billstate == 0 || billstate == 1) {
							self.showBtn({
								title: '微信分享',
								icon: 'wx'
							});
							self.showBtn({
								title: 'QQ分享',
								icon: 'qq'
							});
							self.showBtn({
								title: '打印',
								icon: 'print'
							});
							if (billstate == 0) {
								self.addSaveBtn(); // 添加保存按钮
								self.showBtn({
									title: '删除',
									icon: 'del'
								});
								self.showDelBtn = true
//								self.showBtn({
//									title: '审核'
//								});
							} else {
//								self.showBtn({
//									title: '反审核'
//								});
							}
						} else {
							api.sendEvent({
								name: api.winName + '-btns-update',
								extra: {
									btns: []
								}
							})
						}

						// 设置单据明细
						var rdetail1 = ret.detail1;
						if (Array.isArray(rdetail1) && rdetail1.length > 0) {
							_.each(rdetail1, function(ele, index, list) {
								ele.moneycode = ret.master.moneycode;
								ele.unitqty = ele.unitquantity || ele.quantity;
								ele.unit = ele.unitname;
								ele.goodMode = ele.oldgoodMode = 'old';
							});
						}
						self.bill.goods = rdetail1;
						_g.setLS('productJson', { // 缓存货品明细
							list: rdetail1 || [],
							amount: ret.master.amount
						});

						self.updateBtns(); // 更新按钮

						self.judgment.canEditPrice = ret.resultData.canEditSPrice; // 是否能否编辑货品单价

						if (ret.master.billstate == 0) {
							self.isEditer = true; // 设置不可编辑
							self.judgment.isCheck = false;
						} else { // 已审批后不可编辑
							self.isEditer = false; // 设置不可编辑
							self.judgment.isCheck = true;
						}
						
						BUSINESS.getAnnex({ // 获取附件数据
							data: {
								id: self.bill.id,
								modId: BUSINESS.param[self.type].modId,
							},
							success: function(ret) {
								self.annex.len = ret.data.detail1.length || 0; // 获取附件数量
								self.annex.dataJson = ret.data.detail1; // 获取附件数据
							}
						});

						self.follow.isShow = true; // 显示跟进记录

						if (api.pageParam.isDetail) { // 处理详情不可编辑
							for(var key in self.edit) {
								self.edit[key] = false;
							}
							self.showDelBtn = false;
							api.sendEvent({
								name: api.winName + '-btns-update',
								extra: {
									btns: []
								}
							})
							self.judgment.isCheck = true;
							self.isEditer = false;
						}
					},
					error: function(err) {
						api.hideProgress();
						_g.toastMsg({
							msg: err.msg
						});
					}
				});
			},
			clearData: function(id){
				var self = this
				if(self.bill.master.traderid != id){
					//清空相关机会
					self.bill.master.chanceid = ''
					self.bill.master.chancename = ''
					self.bill.master.chancecode = ''
					//清空货品明细(货品状态：add, old ,edit, delete)
					_.each(self.bill.goods, function(val, key){
						if(val.goodMode != 'add'){
							val.goodMode = 'delete'
						}else{
							self.bill.goods = _.without(self.bill.goods, val)
						}
					})
				}
			},
			initEvent: function() { // 初始化(事件)
				var self = this;
				_g.addEventListener({ // 点击“更多”按钮
					name: api.winName + '-more',
					success: function(ret) {
						api.sendEvent({
							name: api.winName + '-btns-layer',
							extra: {
								type: 'change'
							}
						})
					}
				});
				_g.addEventListener({ // 按钮事件
					name: api.winName + '-btns-layer-selected', //api.winName + '-btns-layer-click',
					success: function(ret) {
						var title = ret.value.selected.title;
						BUSINESS.setData({
							type: self.type, // 业务类型
							mode: self.mode, // 模式
							bill: self.bill, // 数据
							index: self.index
						});
						switch (title) {
							case '删除':
								BUSINESS.del();
								break;
							case '保存':
								if (!BUSINESS.verify()) { // 表单验证
									return;
								}
								BUSINESS.save({
									success: function(ret) {
										console.log('保存');
									}
								});
								break;
							case '打印':
								BUSINESS.print({});
							break;
							case '微信分享':
								BUSINESS.share({
									type: 'wx',
									success: function(ret) {
										console.log('微信分享');
									}
								});
								break;
							case 'QQ分享':
								BUSINESS.share({
									type: 'qq'
								});
								break;
							case '审核':
								BUSINESS.approval({
									tips: '审核'
								});
								break;
							case '反审核':
								BUSINESS.unapproval();
								break;
							default:
						}
					}
				});

				_g.addEventListener({ // 基础资料返回参数事件
					name: api.winName + '-get-winselected', //api.winName + '-list-select',
					success: function(ret) {
						var tag = ret.value.tag; // 基础资料类型
						var data = ret.value.selectedData[0]; // 选择的资料数据
						
						switch (tag) {
							// 客户
							case 'qryTrader':
								//重新选择客户，要清空相关机会和所有的货品明细
								self.clearData(data.clientid)
								self.bill.master.traderid = data.clientid;
								self.bill.master.tradername = data.shortname;
								break;
								// 联系人 
							case 'qryCcontcat':
								self.bill.master.contactid = data.id || '';
								self.bill.master.contactname = data.name || '';
								break;
								// 状态
							case 'qrySalePriceStatus':
								self.bill.master.status = data.id;
								self.bill.master.statusname = data.name;
								break;
							default:
						}
					}
				});

				_g.addEventListener({ // 选择相关机会的事件
					name: 'sale-price-detail-select-work',
					success: function(ret) {
						//获取对应相关机会的商品
						self.getproOfchance(ret.value.datas, function(datas){
							//处理货品明细
							//1.货品明细中，如果显示的货品有上次相关机会对应的货品，，（1）要删除（new->直接删除，old/edit->delete）
							if(self.bill.goods.length != 0){
								var delGoodsId = []
								_.each(self.bill.goods, function(val, key){
									if((val.goodMode == 'old' || val.goodMode == 'edit') && (val.referbillid == self.bill.master.chanceid || val.referbilltype == 150)){
										//把goodMode改为delete
										val.oldgoodMode = val.goodMode
										val.goodMode = 'delete'
									}else if(val.goodMode == 'add' && val.isSelected != true && (val.referbillid == self.bill.master.chanceid || val.referbilltype == 150)){
										//直接删除
										delGoodsId.push(val.goodsid)
									}
								})
								if(delGoodsId.length != 0){
									_.each(delGoodsId, function(sval, skey){
										_.find(self.bill.goods, function(val){
											if(val.goodsid == sval) {
												self.bill.goods = _.without(self.bill.goods, val) //删除
											}
										})
									})
								}
							}
							//2.假如之前有删除选中的货品(只针对edit/old)，已标注为“delete”，则把对应的货品删除。添加之前已有的货品，并标注为edit,添加新增的货品，标注为add
							var sameGoods = []  //记录之前有删除选中的货品在self.bill.goods的索引
							if(datas.length != 0){
								_.each(datas, function(sval, skey){
									_.each(self.bill.goods, function(val, key){
										if(val.goodsid == sval.goodsid && val.selected){
											sval.goodMode = 'edit'
											sameGoods.push({goodsid: val.goodsid})
											return
										}
									})
								})
							}
							if(sameGoods.length != 0){
								_.each(sameGoods, function(sval, skey){
									_.find(self.bill.goods, function(val){
										if(val.goodsid == sval.goodsid) {
											self.bill.goods = _.without(self.bill.goods, val) //删除
										}
									})
								})
								console.log(JSON.stringify(self.bill.goods))
							}
							//添加选中的货品，并标注为edit
							_.each(datas, function(sval, skey){
								self.bill.goods.push(sval)
							})
							//3.处理货品的合计
							var amount = 0
							_.each(self.bill.goods, function(val, key){
								if(val.goodMode != 'delete'){
									amount = amount + val.amount * 1
								}
							})
							self.bill.master.amount = amount
						})
						

						//设置选中的相关机会
						self.bill.master.chanceid = ret.value.datas.billid
						self.bill.master.chancename = ret.value.datas.billcode
						//self.bill.master.chancecode = ret.value.datas.billcode
						
					}
				});

				_g.addEventListener({ // 货品操作事件
					name: 'goods-update',
					success: function(ret) {
						console.log(ret.value);
						if(ret.value.type == 'price'){
							//alert('this:'+JSON.stringify(ret.value))
							var mode = ret.value.mode;
							var goodMode = ret.value.goodMode; // 货品模式(old:单据本身货品, add:新增, edit:编辑过, del:已删除)
							var goods = ret.value.goods; // 货品数据
							switch(mode) {
								case 'save':
									if (goodMode == 'new' || goodMode == 'add') {
										_.each(goods, function(ele, index, list){
											ele.oldgoodMode = ele.goodMode = 'add';
											ele.isSelected = true;
											ele.unitqty = ele.qty;
											ele.unitquantity = ele.quantity;
											ele.price = parseFloat(ele.price).toFixed(2);
											self.bill.goods.unshift(ele); // 更新列表
										})
										
										console.log(JSON.stringify(self.bill.goods))
									} else { // add、edit、old
										if(goodMode == 'old'){ // 标识原有货品已被编辑状态
											goods.oldgoodMode == goods.goodMode
											goods.price = parseFloat(goods.price).toFixed(2)
											goods.goodMode = 'edit';
										}
										goods.unitqty = goods.qty;
										goods.unitquantity = goods.quantity;
										Vue.set(self.bill.goods, self.bill.openGoodsIndex, goods)// 更新所编辑货品的数据
									}
									break;
								case 'del':
									if (goodMode == 'edit' || goodMode == 'old') { // 如果是本来有的货品才需要提交到被删除的货品列表
										self.bill.delGoods.push(self.bill.goods[self.bill.openGoodsIndex]);
									}
									Vue.set(self.bill.goods[self.bill.openGoodsIndex], 'goodMode', 'delete');// 移除数据
									break;
							}
			    			// 更新合计
			    			var amount = 0;
							_.each(self.bill.goods, function(ele, index, list){
								if(ele.goodMode != 'delete'){
									amount += Number(ele.amount);
								}
								
							});
							self.bill.master.amount = parseFloat(amount).toFixed(2);
	
							_g.setLS('productJson', { // 缓存货品明细
								list: self.bill.goods,
								amount: self.bill.master.amount
							});
						}
					}
				});

				_g.addEventListener({ // 附件统计数量统计事件
					name: 'annex-num',
					success: function(ret) {
						if (ret.value.type == 'add') {
							self.annex.len += 1;
						} else {
							self.annex.len -= 1;
						}
					}
				});
			},
			addSaveBtn: function() { // 添加保存按钮
				var self = this;
				self.showBtn({
					title: '保存',
					icon: 'save'
				});
				api.sendEvent({
					name: api.winName + '-btns-add',
					extra: {
						start: 0,
						btn: {
							event: api.winName + '-save',
							icon: 'save'
						}
					}
				})
			},
			changeEvent: function() { // 页面改变事件
				var self = this;
				self.$watch('bill.master.tradername', function(val, oldVal) { // 重选客户后清除已选联系人
					self.bill.master.contactid = '';
					self.bill.master.contactname = '';
					self.bill.master.tradername = val;
				});
			},
			onTapDel: function() { // 删除
				api.sendEvent({
					name: api.winName + '-btns-layer-click',
					extra: {
						btn: {
							title: '删除'
						}
					}
				})
			},
			onTapGetDate: function(key) { // 日期选择
				console.log(key)
				var self = this;
				TIME.getPickerDates(self.bill.master[key], function(chooseDate) {
					self.bill.master[key] = chooseDate;
				});
			},
			onTapChooseChance: function(){ // 打开选择相关机会
				var self = this;
				var traderid = self.bill.master.traderid;
				if(BUSINESS.checkNull(traderid) == ''){
					_g.toastMsg({
						msg: '请先选择客户!'
					}); 
					return;
				}
				_g.openWin({
					name: 'work',
					url: 'work',
					pageParam: {
						parWin: api.winName,
						type: self.type,// 单据类型
						param: { // 相关业务请求参数
							moneyid: 0,// 币种id
							pageSize: 10000,
							traderid: traderid,// 客户id
							startdate: TIME.getDates().sDate,
							enddate: TIME.getDates().eDate
						},
					}
				});
			},
			onTapChooseGoods: function() { // 选择货品
				var self = this;
				var store_billData = {
		          'traderID': self.bill.master.traderid || 0,//客户或/供应商id
		          'noteType': 3, //发票类型为“收据”是1，其他0
		          'storeID': -1//仓库id
		        }
		        $api.setStorage('store_billData', store_billData);
		  //       _g.openWin({
				// 	name: 'pro_choose',
				// 	url: api.wgtRootDir + '/html/oldBusiness/pro_choose',
				// 	pageParam: {
				// 		type: self.type, // 单据类型
				// 		parWin: api.winName,
				// 		parFrame: api.frameName,
				// 		act: 'add' // 是否能够编辑
				// 	}
				// });
				_g.openWin({
					name: 'pro-choose',
					url: 'pro-choose',
					pageParam: {
						type: self.type, // 单据类型
						parWin: api.winName,
						parFrame: api.frameName,
						act: 'add' // 是否能够编辑
					}
				});

				
				// var master = self.bill.master;
				// var isPurReturn = 0; // 是否在采购开单中单据类型是否为采购退货

				// var notetype = master.notetype || 0; //发票类型
				// var tradertaxrate = master.tradertaxrate || 0; //客户或/供应商的税率
				// _g.openWin({
				// 	name: 'product-choose',
				// 	url: 'product-choose-erp',
				// 	pageParam: {
				// 		type: self.type, // 单据类型
				// 		mode: self.mode, // 单据模式
				// 		parWin: api.winName,
				// 		parFrame: api.frameName,
				// 		isEditer: self.isEditer, // 是否能够编辑
				// 		isCheck: self.judgment.isCheck, // 是否为审核状态
				// 		billkind: master.billkind, // 单据类型
				// 		traderid: master.traderid || 0, // 供应商/客户id
				// 		tradertaxrate: tradertaxrate, // 供应商/客户税率
				// 		isRetrun: 1,
				// 		billdate: master.billdate, // 日期
				// 		notetype: master.notetype, // 发票类型
				// 		billtype: 151,
				// 		isPurReturn: isPurReturn, // 是否为采购退货（单据类型）
				// 		vipid: master.vipid, // 会员id
				// 		canEditPrice: self.judgment.canEditPrice // 是否能够修改货品单价
				// 	}
				// });
			},
			onTapOpenGoods: function(item, index) { // 打开货品详情
				var self = this;
				var master = self.bill.master;
				var isPurReturn = 0; // 是否在采购开单中单据类型是否为采购退货

				var notetype = master.notetype || 0; //发票类型
				var tradertaxrate = master.tradertaxrate || 0; //客户或/供应商的税率

				self.bill.openGoodsIndex  = index; //记录打开的货品序号
				var goodMode = item.goodMode || '';// 货品明细状态(old:单据本身货品, add:新增, edit:编辑过, del:已删除)

				_g.setLS('productItem', item);
				var store_billData = {
		          'traderID': self.bill.master.traderid || 0,//客户或/供应商id
		          'noteType': 3, //发票类型为“收据”是1，其他0
		          'storeID': -1//仓库id
		        }
		        $api.setStorage('store_billData', store_billData);
		        _g.openWin({
					name: 'pro_choose',
					url: api.wgtRootDir + '/html/oldBusiness/pro_edit',
					pageParam: {
						type: self.type, // 单据类型
						parWin: api.winName,
						parFrame: api.frameName,
						data: JSON.stringify(item),
						act: 'edit' // 是否能够编辑
					}
				});
			},
			onTapOpenBase: function(key) { // 打开基础资料选择页面
				console.log(key);
				var self = this;
				var param = {};
				var traderid = self.bill.master.traderid || '';
				if (key == 'qryCcontcat' && traderid == '') {
					_g.toastMsg({
						msg: '请先选择客户!'
					});
					return;
				}
				switch(key){
					case 'qryTrader':  //客户
						param.title = '客户';
						param.tag = 'qryTrader';
						param.showName = ['shortname'];
						param.extraParams = {
							filter: "CLOSED='F' and phoneapply='T'",
							viewname: 'client_ds',
							modId: 151
						};
					break;
					case 'qryCcontcat':  //联系人
						param.title = '联系人';
						param.tag = 'qryCcontcat';
						param.showName = ['name'];
						param.extraParams = {
							filter: 'clientid=' + traderid + ' and closed=0',
							modId: 151
						}
					break;
					case 'qrySalePriceStatus':  //状态
						param.title = '状态';
						param.tag = 'qrySalePriceStatus';
						param.showName = ['name'];
						
					break;
				}
				_g.openWin({
					name: 'list-select',
					url: '../Common/list-select',
					pageParam: {
						isMultiSelect: false,
						title: param.title,
						tag: param.tag,
						frameName: api.winName,
						showName: param.showName,
						hasSearch: false,
						filter: param.filter,
						extraParams: param.extraParams
					}
				});



				// var baseData = {};
				// if (key == 'qryCcontcat') {
					
				// 	baseData = BUSINESS.interface.base[key]({
				// 		traderid: traderid,
				// 		modId: BUSINESS.param[self.type].modId
				// 	});
				// } else {
				// 	baseData = BUSINESS.interface.base[key]({
				// 		modId: BUSINESS.param[self.type].modId
				// 	});
				// 	if(key == 'qryTrader'){
				// 		baseData.param = $.extend(baseData.param, {
				// 			filter: "CLOSED='F' and phoneapply='T'",
				// 			viewname: 'client_ds',
				// 			modId: 151
				// 		});
				// 	}
				// }
				// _g.openWin({
				// 	name: 'list-select',
				// 	url: './list-select',
				// 	pageParam: {
				// 		eventName: api.winName + '-list-select',
				// 		billType: self.type,
				// 		type: key,
				// 		title: baseData.title,
				// 		url: baseData.url,
				// 		params: baseData.param
				// 	}
				// });
			},
			onTapOpenAnnex: function() { // 打开附件
				var self = this;
				_g.openWin({
					name: 'annex',
					url: '../Annex/annex',
					pageParam: {
						paramJson: {
							readOnly: !self.isEditer,
							isDetail: self.mode == 'edit' ? true : false, // 单据是否为详情情况
							param: {
								id: self.bill.id, // 单据id
								modId: BUSINESS.param[self.type].modId, // 业务类型modId
							},
							dataJson: self.annex.dataJson, // 附件数据
						}
					}
				});
			},
			onTapOpenFollow: function() { // 打开跟进记录（获取客户跟进列表）
				var self = this;
				_g.openWin({
					name: 'follow',
					url: '../Index/follow',
					pageParam: {
						referbillid: self.bill.id, // 单据id
						title: '客户跟进记录',
						from: 'bussiness',
						bparam: {
							dsbilltype: { // 业务类型
								id: BUSINESS.param[self.type].modId,
								name: BUSINESS.param[self.type].title,
								code: BUSINESS.param[self.type].code
							},
							followBill: { // 跟进单据
								id: self.bill.master.id,
								name: self.bill.master.name,
								code: self.bill.master.code
							}
						}
					}
				});
			}
		},
		created: function() {
			console.log(_g.j2s(api.pageParam));
			var self = this;
			self.init();
		},
		mounted: function() {
			var self = this;
		}
	});
});
