define(function (require, exports, module) {
	var BLE = require('ble/blePrinter');
	var http = require('http');
	var MODULES = require('modules');
	var COMMAND = require('command');
	var INTERFACE = require('interface')
	var TIME = require('time')
	var stime = TIME.getDates().sDate
	var etime = TIME.getDates().eDate

	var content = new Vue({
		el: '#content',
		data: {
			listData:[],
			sortArray: {},
			showNums: 10, //默认显示前10条
			currentFrame: 'charts-by-client', //当前选中的frame
			showFilterName: ['显示前10条'],
			params: {
				beginDate: stime,
				endDate: etime,
				shopid: _g.getLS('shopID')
			}
		},
		methods: {
			ajax: function(){
				var self = this
				var dtd = new $.Deferred();	
				COMMAND.init({
					url: INTERFACE.report.saleCharts.urlByClient,
					data: $.extend(INTERFACE.report.saleCharts.param, self.params),
					hideProgress: true,
					success:function(ret){
						self.listData = ret.resultData.ReportData;
						dtd.resolve();
					}
				})
				return dtd.promise();
			},
			sortData: function(){
				//对数据进行处理
				var self = this;
				var dtd = new $.Deferred();
				self.sortArray = {};
				_.each(self.listData, function(val, key){
					if (val.rtype != 99) { //99为合计，不显示
						if (self.sortArray[val.clientid]) {
							//已存在
							self.sortArray[val.clientid] = {
								amount: self.sortArray[val.clientid]['amount'] * 1 + val.amount * 1,
								name: val.name
							}
						} else {
							self.sortArray[val.clientid] = {
								amount: val.amount * 1,
								name: val.name
							}
						}
					}
					
				})
				dtd.resolve();
				return dtd.promise();
			},
			toFixed: function(num){
				return (Number(num)/10000).toFixed(6);
			},
			renderChart: function(){
				//渲染图标
				var self = this;
				var yData = [];
				var xData = [];
				_.each(self.sortArray, function(val, key){
					val.amount = self.toFixed(val.amount);
					yData.push(val.amount);
				})
				//y轴数组，由大到小排序
				yData = yData.sort(function(a, b){
					return b-a
				})
				yData = yData.slice(0, self.showNums);
				//根据y轴数组，创建x轴数组
				$.each(yData, function(key, yval){
					$.each(self.sortArray, function(key, val){
						if (yval == val.amount) {
							console.log(yval+',,'+val.amount)
							xData.push(val.name);
							return false;
						}
					})
				})
				var showLen = 5;
				if (xData.length >5) showLen = 3;
				// 基于准备好的dom，初始化echarts实例
			    var myChart = echarts.init(document.getElementById('main'));
			    var option = {
		            title: {
		                text: ''
		            },
		            tooltip: {},
		            legend: {
		                data:[]
		            },
		            xAxis: {
		            	axisLabel: { //x轴的内容设置
			        		interval: 0, //让每一个x轴的值都显示
			        		align: 'center', //居中显示
			        		margin: 10, 
			        		width: '100%',
			        		verticalAlign: 'top', //文字垂直方式
			        		rotate: 0,  //倾斜的角度
			        		formatter: function(val) { //控制内容显示，如果过长则换行
                                var strs = val.split(''); //字符串数组
                                var str = ''
                                for(var i = 0, s; s = strs[i++];) { //遍历字符串数组
                                    str += s;
                                    if(!(i % showLen)) str += '\n'; //按需要求余
                                }
                                return str
                            }
			        	},
		                data: xData 
		            },
		            yAxis: {
		            	name: '金额（万元）',
		            },
		            series: [{
		                name: '金额',
		                type: 'bar',
		                label: {
			            	show: true,
			            	position: 'top'
			            },
			            itemStyle: {
			            	color: '#ffb451' // 设置柱条的颜色
			            },
		                data: yData
		            }]
		        };

		        // 使用刚指定的配置项和数据显示图表。
		        myChart.setOption(option);
			},
			init: function(){
				var self = this;
				var dtd=new $.Deferred();
				$.when(self.ajax())  //获取数据
				    .then(function () { return self.sortData(); })//整理数据
				    .then(function () { 
				    	self.renderChart()  //渲染图表
				    })
			}	
		},
		created: function() {
			var self = this
			self.init();
		},
		mounted: function() {
			var self = this
			_g.addEventListener({
				name: api.winName + '-change-tab',
				success: function(ret) {
					if(ret.value.index == 0){
						self.currentFrame = 'charts-by-client'
					} else if(ret.value.index == 1){
						self.currentFrame = 'charts-by-product';
					} else {
						self.currentFrame = 'charts-by-clerk'
					}
				}
			})
			// 过滤
	  		if(!_g.getLS('selected-'+api.frameName)) {
	  			// 刚进入列表
	  			var listItem = [];
	  			//仅总部操作员(shopid=0)提供分支机构过滤
	  			if(_g.getLS('shopID') == 0){
	  				listItem.push({
						type:'select-win', 
						title:'分支机构', 
						tag: 'shop', 
						selected: {value: '不限'}
					})
	  			}
	  			listItem.push({
					type:'select-box', //下拉选择
		            title: '显示数据条数', 
		            tag: '', //无tag
		            source: [{
		            	name: '前2条',
		            	showName: '前2条',  
		            	value: 2
		            },{
		            	name: '前4条',
		            	showName: '前4条',
		            	value: 4
		            },{
		            	name: '前6条',
		            	showName: '前6条',
		            	value: 6
		            },{
		            	name: '前8条',
		            	showName: '前8条',
		            	value: 8
		            },{
		            	name: '前10条',
		            	showName: '前10条',
		            	value: 10
		            }], //下拉数据源（必须有name字段）
		            selected: {
		                selectedIndex: (self.showNums-2)/2, //选中项的索引(必要)
		                showName: '前' + self.showNums + '条',
		                name: '前' + self.showNums + '条', //选中的值(必要)
		                value: self.showNums
		            }
				})
	  			var filterData = {
	  				filterName: 'selected-' + api.frameName,
					stage: {
						hasStage: true,
						startTime: stime,
						endTime: etime
					},
					listItem: listItem
				}
				_g.setLS('selected-'+api.frameName, filterData)
	  		}
			_g.addEventListener({
				name: api.winName + '-filter',
				success: function(ret) {
					if (self.currentFrame == 'charts-by-client') {
						// 打开过滤页面
						_g.openWin({
							name:'filter',
							url:'../Common/filter',
							pageParam: _g.getLS('selected-'+api.frameName)
						})
					}
					
				}
			})
			// 监听进行过滤操作
			_g.addEventListener({
				name: 'selected-' + api.frameName + '-filterAction',
				success: function(ret) {
					//获取过滤数据
					var showFilterName = []
					var filterData = _g.getLS('selected-'+api.frameName)
					self.params = {}
					self.params.beginDate = filterData.stage.startTime
		      		self.params.endDate = filterData.stage.endTime
			     	showFilterName.push(self.params.beginDate + '~' + self.params.endDate)
		     		_.each(filterData.listItem, function(val, key){
			     		
	     				switch(val.title){
			     			case '分支机构':
			     				showFilterName.push(val.selected.value)
			     				if (val.selected.value != '不限') {
			     					self.params['shopid'] = val.selected.shopid;
			     				}
			     			break
			     			case '显示数据条数':
			     				showFilterName.push(val.selected.showName)
			     				self.showNums = val.selected.value;
			     			break
			     			default:
			     			break
			     		}
			     	})
			     	self.showFilterName = showFilterName
					// 重新加载
					self.init();
				}
			})
			//监听点击返回按钮后，清除缓存的过滤数据
			_g.addEventListener({
				name: api.winName + '-closeWin',
				success: function(ret) {
					_g.clearFilterLS(api.frameName)
				}
			})
			
			//蓝牙打印
			_g.addEventListener({
				name: api.winName + '-print',
				success: function(ret) {
					var printData = {}
					var content = []
					_.each(self.listData, function(val, key){
						content.push({title: val.name, value: val.qty + '次'})
					})
					printData.content = content

					BLE.setData({
						data:printData.content
					});
					BLE.printEvent();
				}
			})

		}
	});
});
