define(function (require, exports, module) {
	var BLE = require('ble/blePrinter');
	var HTTP = require('http');
	var COMMAND = require('command');
	var INTERFACE = require('interface');
	var TIME = require('time')
	var stime = TIME.getDates().sDate
	var etime = TIME.getDates().eDate
	var content = new Vue({
		el: '#content',
		data: {
			listData:[],
			params: {
				startdate: stime,
				enddate: etime,
				clientid: 0
			},
			lcrealamtSum: 0, //销售净额
			chargedamtSum: 0, // 回款金额
			realchargedamtSum: 0, //实际回款
			chargedrateSum: 0, //回款比率
			showFilterName: [],
			money: []
		},
		methods: {
			clear: function(){
				var self = this
				self.listData = []
				self.lcrealamtSum = 0
				self.chargedamtSum = 0
				self.realchargedamtSum = 0
				self.chargedrateSum = 0
			},
			ajax: function(){
				var self = this
				var param = {}
				param.startdate = self.params.startdate
				param.enddate  = self.params.enddate 
				param.pageSize  = 10000
				if(self.params.clientid != 0){
					param.clientid = self.params.clientid
				}
				COMMAND.init({
					url: INTERFACE.report.url,
					data: $.extend(INTERFACE.report.salesStatistics.param, param),
					hideProgress: true,
					success:function(ret){
						if(ret.errNo == 1){
							_g.toastMsg({
								msg:ret.errMsg
							})
						}else if(ret.errNo == 0){
							if(ret.resultData.ReportData.length != 0){
								var index = 0
								_.each(ret.resultData.ReportData, function(val, ind){
									val.chargedrate = ((val.chargeamt/val.chargefact) * 100).toFixed(2) + '%'
									if(val.name == '合  计'){
										index = ind
										return
									}
								})
								var sum = ret.resultData.ReportData[index]
								self.lcrealamtSum = sum.chargefact || 0 // 销售净额 
								self.chargedamtSum = sum.chargeamt || 0//回款金额
								self.realchargedamtSum = sum.factamt || 0//实际回款
								if(self.chargedamtSum == 0 || self.lcrealamtSum == 0){
									self.chargedrateSum = '0.00%'
								}else {
									self.chargedrateSum = sum.chargedrate
								}
								self.listData = _.without(ret.resultData.ReportData, ret.resultData.ReportData[index])
							}else {
								self.clear()
							}
						}
					}
				})
			}
		},
		created: function() {
			var self = this
			self.ajax()

		},
		mounted: function() {
			var self = this
			
			_g.addEventListener({
				name: api.winName + '-filter',
				success: function(ret) {
					// 过滤
		  		if(!_g.getLS('selected-'+api.frameName)) {
		  			// 刚进入列表
		  			var filterData = {
		  				isReportOrProvider: true,
		  				filterName: 'selected-' + api.frameName,
							stage: {
								hasStage: true,
								startTime: stime,
								endTime: etime
							},
							listItem:[{
								type:'select-win', title:'客户', tag: 'trader', selected: {value: '不限'}, extraParams: {filter: '(isclient=1 or acctrader =1) and Closed=0 and TraderID>0'}
							}]
						}
						_g.setLS('selected-'+api.frameName, filterData)
		  		}
					// 打开过滤页面
					_g.openWin({
						name:'filter',
						url:'../Common/filter',
						pageParam: _g.getLS('selected-' + api.frameName)
					})
				}
			})
			// 监听进行过滤操作
			_g.addEventListener({
				name: 'selected-' + api.frameName + '-filterAction',
				success: function(ret) {
					//获取过滤数据
					var showFilterName = []
					var filterData = _g.getLS('selected-'+api.frameName)
					self.params.startdate = filterData.stage.startTime
				    self.params.enddate = filterData.stage.endTime
				    showFilterName.push(self.params.startdate + '~' + self.params.enddate)
			     	_.each(filterData.listItem, function(val, key){
			     		
			     		if(val.selected.showName) {
	     					showFilterName.push(val.selected.showName)
	     				}
	     				switch(val.title){
			     			case '客户':
			     				self.params.clientid = val.selected.clientid
			     			break
			     			default:
			     			break
			     		}
			     	})
			     	self.showFilterName = showFilterName
					// 重新获取数据
					self.ajax()
				}
			})
			//监听点击返回按钮后，清除缓存的过滤数据
			_g.addEventListener({
				name: api.winName + '-closeWin',
				success: function(ret) {
					_g.clearFilterLS(api.frameName)
				}
			})

				//蓝牙打印
			_g.addEventListener({
				name: api.winName + '-print',
				success: function(ret) {
					var printData = {}
					var content = []

					_.each(self.listData, function(val, key){
						content.push({value: val.name, big: true})
						content.push({title: '销售净额', value: val.lcrealamt})
						content.push({title: '回款金额', value: val.chargedamt})
						content.push({title: '实际回款', value: val.realchargedamt})
						content.push({title: '回款比率', value: val.chargedrate + '%'})
					})

					content.push({value:'\n'});
					var lcrealamtSum = self.lcrealamtSum >= 0 ? self.lcrealamtSum : -self.lcrealamtSum;
					var chargedamtSum = self.chargedamtSum >= 0 ? self.chargedamtSum : -self.chargedamtSum;
					var realchargedamtSum = self.realchargedamtSum >= 0 ? self.realchargedamtSum : -self.realchargedamtSum;
					var chargedrateSum = self.chargedrateSum >= 0 ? self.chargedrateSum : -self.chargedrateSum;
					content.push({value: '销售净额:' + self.lcrealamtSum + '   回款金额:' + self.chargedamtSum, bold: true})
					content.push({value: '实际回款:' + self.realchargedamtSum + '   回款比率:' + self.chargedrateSum + '%', bold: true})
					printData.content = content

					BLE.setData({
						data:printData.content
					});
					BLE.printEvent();
				}
			})
		}
	});
});
