define(function(require, exports, module) {

	var BLE = require('ble/blePrinter')

	var content = new Vue({
		el: '#content',
		template: _g.getTemplate('Set/print-frame-v'),
		data: {
			showScanPanel: false,
			activeUUID: '',
			activeNewItem: {},
			activeOldItem: {},
			oldDevices: [],
			newDevices: []
		},
		methods: {
			init: function() { // 初始化
				var self = this;
				// BLE.startScan(); // 初始化并扫描设备
				self.oldDevices = self.getOldList() || []; // 获取已配对的设备，并显示到列表
			},
			scan: function() { // 扫描蓝牙打印机
				var self = this;
				_g.showLoading({
					title: '扫描中...'
				});
				BLE.startScan();
				BLE.getPeripheral({
					success: function(ret) {
						console.log(_g.j2s(ret));
						var peripherals = ret.peripherals || [];
						var tempNewDevices = [];
						_.each(peripherals, function(ele, index, list) {
							if (BLE.isPrint(ele)) {
								ele.active = false;
								tempNewDevices.push(ele);
							}
						});
						if (tempNewDevices.length == 0) {
							_g.toastMsg({
								msg: '未找到任何蓝牙打印机'
							});
						} else {
							self.newDevices = tempNewDevices;
							self.showScanPanel = true;
						}
					}
				});
				api.hideProgress();
			},
			closeScanPanel: function() { // 关闭扫描面板
				var self = this;
				self.showScanPanel = false;
			},
			getOldList: function() { // 获取已配对设备
				return _g.getLS('bleList');
			},
			setOldList: function(opts) { // 缓存已配对设备
				var self = this;
				var hasPair = false;
				var activeNewItem = opts.activeNewItem;
				_.each(self.oldDevices, function(ele, index, list) {
					if (activeNewItem.uuid == ele.uuid) {
						hasPair = true;
						_g.toastMsg({
							msg: '该蓝牙打印机已配对'
						});
						return;
					}
				});
				if (!hasPair) {
					self.oldDevices.push(activeNewItem); // 显示到列表
					_g.setLS('bleList', self.oldDevices); // 缓存已配对设备
					$api.setStorage('bleList', self.oldDevices); // 缓存已配对设备
					$api.setStorage('bleList', self.oldDevices);
					self.closeScanPanel();
				}
			},
			setConnectBle: function(opts) { // 设置连接的蓝牙设备
				var self = this;
				_g.setLS('connectBle', opts.ble);
				$api.setStorage('connectBle', opts.ble);
			},
			connect: function() { // 配对蓝牙
				var self = this;
				if (_g.j2s(self.activeNewItem) != '{}') {
					self.activeNewItem.active = false;
					self.setOldList({
						activeNewItem: self.activeNewItem
					});
				} else {
					_g.toastMsg({
						msg: '请选择需要配对的蓝牙打印机'
					});
				}
			},
			chooseOldDevice: function(item) { // 勾选需要连接的蓝牙设备
				var self = this;
				if (item.active) {
					item.active = false;
					self.activeOldItem = {};
					return;
				}
				_.each(self.oldDevices, function(ele, index, list) {
					ele.active = false;
				});
				item.active = true;
				self.activeOldItem = item;
			},
			chooseNewDevice: function(item) { // 勾选扫描到的新设备
				var self = this;
				if (item.active) {
					item.active = false;
					self.activeNewItem = {};
					return;
				}
				_.each(self.newDevices, function(ele, index, list) {
					ele.active = false;
				});
				item.active = true;
				self.activeNewItem = item;
			}
		},
		created: function() {
			console.log(_g.j2s(api.pageParam));
			var self = this;
			self.init();
		},
		mounted: function() {
			var self = this;

			_g.addEventListener({ // 确定
				name: api.winName + '-right',
				success: function(ret) {
					if (_g.j2s(self.activeOldItem) == '{}') {
						_g.toastMsg({
							msg: '请选择蓝牙打印机'
						});
						return;
					}
					self.setConnectBle({
						ble: self.activeOldItem
					});
					if (api.pageParam.mode == 'auto' && api.pageParam.mode == 'new') {
						setTimeout(function() {
							api.sendEvent({
								name: 'new-printer-print-auto'
							});
						}, 500);
					}else if(api.pageParam.mode == 'auto' && api.pageParam.mode == 'old'){
						setTimeout(function() {
							api.sendEvent({
								name: 'old-printer-print-auto'
							});
						}, 500);
					}
					setTimeout(function() {
						api.closeWin({
							name: api.winName
						});
					}, 800);
				}
			});
		}
	});
});
