define(function(require, exports, module) {
	/**
	 * [Gprinter 佳博蓝牙热敏式打印机]
	 */
	var ble = api.require('ble');

	function Gprinter() {
		this._bleData = {}; // 连接数据
		this._peripherals = []; // 扫描的数据
		this._uuid = ''; // 连接的蓝牙地址
		this._serviceUUID = ''; // 连接的蓝牙服务
		this._characteristicUUID = ''; // 连接的蓝牙特征
		this._state = 0; // 连接状态（0：未连接，1：已连接）
	}

	Gprinter.prototype = {
		init: function(opts) {
			console.log('初始化');
			var self = this;
			ble.initManager(function(ret, err) { // 初始化蓝牙4.0
				if (ret.state == 'poweredOn') { // poweredOn：设备开启状态 -- 可用状态
					self._state = 1;
					opts.success && opts.success(ret);
				} else {
					switch (ret.state) {
						case 'poweredOff':
							_g.toastMsg({
								msg: '请打开手机蓝牙'
							});
							break;
						case 'resetting':
							_g.toastMsg({
								msg: '正在重置状态'
							});
							break;
						case 'unauthorized':
							_g.toastMsg({
								msg: '该应用没有蓝牙权限'
							});
							break;
						case 'unknown':
							_g.toastMsg({
								msg: '未知错误'
							});
							break;
						case 'unsupported':
							_g.toastMsg({
								msg: '该设备不支持蓝牙4.0'
							});
							break;
					}
					//poweredOff：设备关闭状态
					//resetting：正在重置状态
					//unauthorized：设备未授权状态
					//unknown：初始的时候是未知的
					//unsupported：设备不支持的状态
					opts.error && opts.error(err);
				}
			});
		},
		scan: function(opts) { // 开始搜索蓝牙4.0设备
			console.log('扫描');
			var self = this;
			ble.scan(function(ret, err) {
				console.log(_g.j2s(ret));
				if (ret.status) {
					opts.success && opts.success(ret);
				} else {
					opts.error && opts.error(err);
				}
			});
		},
		stopScan: function() { // 停止搜索蓝牙4.0设备
			console.log('停止扫描');
			var self = this;
			ble.stopScan();
		},
		getPeripheral: function(opts) { // 获取当前扫描到的所有外围设备信息
			console.log('获取当前扫描到的所有外围设备信息');
			var self = this;
			ble.getPeripheral(function(ret, err) {
				console.log(_g.j2s(ret));
				self._peripherals = ret.peripherals;
				opts.success && opts.success(ret);
			});
		},
		connect: function(opts) { // 连接蓝牙4.0设备
			console.log('连接蓝牙4.0设备');
			var self = this;
			ble.connect({
				peripheralUUID: self._uuid
			}, function(ret, err) {
				if (ret.status) {
					opts.success && opts.success(ret);
				} else {
					opts.error && opts.error(err);
				}
			});
		},
		disconnect: function(opts) { // 断开蓝牙4.0设备
			console.log('断开蓝牙4.0设备');
			var self = this;
			ble.disconnect({
				peripheralUUID: self._uuid
			}, function(ret, err) {
				if (ret.status) {
					opts.success && opts.success(ret);
				} else {
					opts.error && opts.error(err);
				}
			});
		},
		isConnect: function(opts) { // 判断是否为连接状态
			console.log('判断是否为连接状态');
			var self = this;
			ble.isConnected({
				peripheralUUID: self._uuid
			}, function(ret, err) {
				console.log(_g.j2s(ret));
				if (ret.status) {
					opts.success && opts.success(ret);
				} else {
					opts.error && opts.error(err);
				}
			});
		},
		send: function(opts) { // 根据指定的外围设备 UUID 及其服务 UUID 和特征 UUID 写数据
			console.log('根据指定的外围设备 UUID 及其服务 UUID 和特征 UUID 写数据');
			var self = this;
			ble.writeValueForCharacteristic({
				peripheralUUID: self._uuid,
				serviceUUID: self._serviceUUID,
				characteristicUUID: self._characteristicUUID,
				value: opts.value,
				writeType: opts.writeType || 'response'
			}, function(ret, err) {
				if (ret) {
					opts.success && opts.success(ret);
				} else {
					opts.error && opts.error(err);
				}
			});
		},
		setPeripherals: function(opts) { // 设置外围设备
			var self = this;
			self._peripherals = opts.peripherals || [];
		},
		getPeripherals: function() { // 获取外围设备
			var self = this;
			return self._peripherals;
		},
		setBleData: function(opts) { // 设置蓝牙外围设备的参数
			var self = this;
			self._bleData = opts.bleData || {};
			self._uuid = opts.bleData.uuid || '';
		},
		getBleData: function() { // 获取蓝牙外围设备的参数
			var self = this;
			return self._bleData || '';
		},
		setUUID: function(opts) { // 设置蓝牙外围设备的 UUID
			var self = this;
			self._uuid = opts.uuid || '';
		},
		getUUID: function() { // 获取蓝牙外围设备的 UUID
			var self = this;
			return self._uuid;
		}
	}

	Gprinter.prototype.constructor = Gprinter;
	module.exports = new Gprinter();
});