define(function(require, exports, module) {

	var HTTP = require('http');

	function Command() {
		this._url = '';
		this._data = {};
		this._method = 'post';
		this._dataBackup = {}; //初始化参数备份
		this._pageSize = 10; //每页显示个数
		this._pageSizeKey = 'pageSize'; // 请求页码的键名
		this._pageNum = 0; //总页数
		this._nowPageNum = 0;
		this._totalCount = 1; //总个数
		this._filterJson = {}; //筛选条件
	}

	Command.prototype = {
		ajax: function(opts) { // 请求
			var self = this;
			HTTP.ajax({
				url: self._url,
				data: self._data,
				method: self._method,
				success: function(ret) {
					opts.success && opts.success(ret);
				},
				other: function(ret) {
					opts.other && opts.other(ret);
				},
				error: function(err) {
					_g.toastMsg({
						msg: err.msg
					});
					opts.error && opts.error(err);
				},
				extraFunc: function(ret) {
					opts.extraFunc && opts.extraFunc(ret);
				}
			});
		},
		init: function(opts) { // 初始化
			var self = this;
			_g.showLoading({
				title: '加载中...'
			});
			self._url = opts.url;
			self._data = opts.data || {};
			self._method = opts.method || 'post';
			self._hideProgress = opts.hideProgress || false;
			self._dataBackup = $.extend({}, opts.data || '');
			self.setPageSize(self._data[self._pageSizeKey] || self._pageSize);
			self.ajax({
				success: function(ret) {
	     			self.countPage(ret);
					opts.success && opts.success(ret);
				},
				extraFunc: function(ret){
					self.countPage(ret);
					opts.extraFunc && opts.extraFunc(ret);
				}
			});
		},
		initData: function() { // 重新初始化数据
			var self = this;
			self._data = $.extend({}, self._dataBackup);
			self.setPageSize(self._pageSize);
		},
		setData: function(opts) { // 设置请求参数
			var self = this;
			self._url = opts.url;
			self._data = opts.data;
			self._dataBackup = $.extend({}, opts.data || '');
			self.setPageSize((opts._data && opts._data.pageSize) || self._pageSize);
		},
		setPageKey: function(opts) { // 设置请求页码的key
			var self = this;
			self._pageKey = opts.key;
		},
		setPageSizeKey: function(opts) { // 设置请求每页个数的key
			var self = this;
			self._pageSizeKey = opts.key;
		},
		setPageSize: function(pageSize) { // 设置每页显示页数
			var self = this;
			self._pageSize = pageSize;
			self._data[self._pageSizeKey] = pageSize;
			self._data.start = 0;
		},
		countPage: function(opts) { // 计算页数
			var self = this;
			var data = opts.data || '';
			var listData = opts.listData || '';
			var resultData = opts.resultData || '';
			var clientclassList = opts.clientclassList || '';
			var countNum = 0;
			if (data !== '') {
				countNum = opts.data.totalCount;
			}
			if (listData !== '' || resultData !== '' || clientclassList !== '') {
				countNum = opts.count;
			}
			self._pageNum = Math.floor(countNum / self._pageSize);
			self._nowPageNum = 0;
			if (countNum % self._pageSize > 0) {
				self._pageNum += 1;
			}
		},
		refresh: function(opts) { //刷新
			var self = this;
			api.sendEvent({
				name: api.winName + '-search-clear'
			});
			if(opts.modify){
				if(opts.modify.hasOwnProperty('filterItemRelation')){
					self._dataBackup.filterItemRelation = opts.modify.filterItemRelation
				}
				if(opts.modify.hasOwnProperty('filter')){
					self._dataBackup.filter = opts.modify.filter
				}
				if(opts.modify.hasOwnProperty('likeValue')){
					self._dataBackup.likeValue = opts.modify.likeValue
				}
			}
			if(opts.deleted){
				_.each(self._dataBackup, function(val, index){
					if(index.indexOf(opts.deleted.filterStr) > -1){
						delete self._dataBackup[index]
					}
				})
				
			}
			if(self._dataBackup.searchkey){
				self._dataBackup.searchkey = ''
			}
			if(self._dataBackup.searchKey){
				self._dataBackup.searchKey = ''
			}
			self.initData();
			self.ajax({
				success: function(ret) {
	     		self.countPage(ret);
					opts.success && opts.success(ret);
					_g.refreshDone();
					_g.toastMsg({
						msg: '已刷新'
					});
				},
				other: function(ret) {
					_g.refreshDone();
				},
				error: function(err) {
					_g.refreshDone();
				},
				extraFunc: function(ret){
					_g.refreshDone();
				}
			});
		},
		next: function(opts) { // 下一页
			var self = this;
			console.log(self._pageNum)
			if (self._pageNum > 0) {
				var nowPageNum = self._nowPageNum;
				nowPageNum += 1;
				self._data.start += Number(self._data[self._pageSizeKey]);
				if (nowPageNum <= self._pageNum) {
					_g.showLoading({
						title: '加载中...'
					});
					self.ajax({
						success: function(ret) {
							_g.refreshDone();
							opts.success && opts.success(ret);
							self._nowPageNum += 1;
						},
						extraFunc: function(ret){
							_g.refreshDone();
							opts.extraFunc && opts.extraFunc(ret);
							self._nowPageNum += 1;
						}
					});
				} else {
					_g.toastMsg({
						msg: '已加载全部'
					});
				}
			} else {
				_g.toastMsg({
					msg: '已加载全部'
				});
			}
		},
		search: function(opts) { //搜索
			var self = this;
			self.initData();
			$.extend(self._data, opts.searchJson);
			self.ajax({
				success: function(ret) {
	     			self.countPage(ret);
					opts.success && opts.success(ret);
				},
				extraFunc: function(ret){
					self.countPage(ret);
					opts.extraFunc && opts.extraFunc(ret);
				}
			});
		},
		filter: function(opts) { //筛选
			var self = this;
			self.initData();
			$.extend(self._data, opts.filterJson);
			self.ajax({
				success: function(ret) {
	     			self.countPage(ret);
					opts.success && opts.success(ret);
				},
				extraFunc: function(ret){
					self.countPage(ret);
					opts.extraFunc && opts.extraFunc(ret);
				}
			});
		}
	}

	Command.prototype.constructor = Command;
	module.exports = new Command();
});
