define(function(require, exports, module) {

	var fs = api.require('fs');
	var MODULES = require('modules');
	var docInteraction = api.require('docInteraction');

	function file() {}

	file.prototype = {
		isPic: function(fileType) { // 判断为图片类型
			return /^(jpg|bmp|gif|ico|pcx|jpeg|tif|png|raw|tga)$/.test(fileType);
		},
		isDoc: function(fileType) { // 判断为文档类型
			return /^(excel|doc|pdf|docx|txt)$/.test(fileType);
		},
		isAudio: function(fileType) { // 判断音频类型
			return /^(amr|mp3|ogg)$/.test(fileType);
		},
		exist: function(opts) { // 判断文件是否存在
			if (opts.path === '') {
				return false;
			}
			var ret = fs.existSync({
				path: opts.path
			});
			if (ret.exist && !ret.directory) {
				console.log('fileExist succ: ' + JSON.stringify(ret));
				opts.success && opts.success(ret);
				return true;
			} else {
				console.log('fileExist err: ' + JSON.stringify(ret));
				opts.error && opts.error(ret);
				return false;
			}
		},
		download: function(opts) { // 下载文件
			var self = this;
//			if (!/^htt(p|ps):\/\/([\w-]+\.)+[\w-]+(\/[\w-.\/?%&=]*)?$/.test(opts.url)) {
//				console.log(opts.url);
//				_g.toastMsg({msg: '无法下载，该文件地址有误'});
//				return;
//			}
			_g.showLoading({
				title: '下载中',
				text: '请稍等片刻...',
			});
			api.download({
				url: opts.url,
				savePath: opts.savePath, // (opts.dir || 'fs://download/') + (opts.fileName || self.getFullNameByPath(opts.url)),
				report: opts.report || true,
				cache: opts.cache || true,
				allowResume: opts.allowResume || true
			}, function(ret, err) {
				_g.hideProgress();
				if (ret) {
					if (ret.state == 1) {
						_g.toastMsg({msg: '下载成功'});
						opts.success && opts.success(ret);
					} else {
						_g.toastMsg({msg: '下载失败'});
					}
				} else {
					opts.error && opts.error(err);
					_g.toastMsg({msg: '下载失败'});
				}
			});
		},
		open: function(opts) { // 打开文件
			if (opts.path == '') {
				_g.toastMsg({msg: '无法打开该文件'});
				return;
			}
			var self = this;
			var fileName = self.getFullNameByPath(opts.path);
			// 获取文件类型
			var type = self.analyze(fileName);
			if (api.systemType == 'android') {
				docInteraction.open({
					path: opts.path
				}, function(ret, err) {
					if (ret) {
						  if(!ret.status){
						  	_g.toastMsg({msg:'无法打开该文件'});
						  }
					} else {
						if (err.code == 1) {
							_g.toastMsg({msg:'未找到可以打开该文件类型的应用'});
						} else {
							_g.toastMsg({msg:'无法打开该文件'});
						}
					}
				});
			} else {
				// 判断文件类型
				switch (type) {
					case 'image':
						MODULES.photoBrowser({
							images: [opts.path],
						});
						break;
					case 'txt':
						MODULES.docReader({
							path: opts.path
						});
						break;
					default:
						_g.toastMsg({msg:'无法打开该类型文件'});
				}
			}
		},
		analyze: function(fileFullName) { // 解析文件类型
			var self = this;
			if (fileFullName == '') {
				return 'unknow'
			}
			var fileType = self.getTypeByPath(fileFullName); // 获取文件类型
			var type = 'unknow';
			switch (true) {
				case /^(jpg|JPG|bmp|BMP|gif|GIF|ico|ICO|jpeg|JPEG|png|PNG)$/.test(fileType):
					type = 'image';
					break;
				case /^(doc|DOC|docx|DOCX|xlsx|XLSX|pptx|PPTX|pdf|PDF|txt|TXT)$/.test(fileType):
					type = 'txt';
					break;
			}
			return type;
		},
		getTypeByPath: function(path) { // 根据文件位置获取文件类型
			var num = path.split('.'); //分割文件名
			var fileType = num[num.length - 1];
			return fileType;
		},
		getFullNameByPath: function(path) { // 根据路径或链接获取文件名+文件类型
			var num = path.split('/'); //分割文件名
			var fileName = num[num.length - 1];
			return fileName;
		}
	}

	file.prototype.constructor = file;
	module.exports = new file();
})
