define(function(require, exports, module) {
	/**
	 * [Modules APICloud模块集]
	 */
	function Modules() {}

	Modules.prototype = {
		fileBrowser: function(opts) { // 文件浏览选择
			var fileBrowser = api.require('fileBrowser');
			fileBrowser.open(function(ret, err) {
				if (ret) {
					fileBrowser.close();
					opts.success && opts.success(ret);
					console.log('fileBrowser succ: ' + JSON.stringify(ret));
				} else {
					fileBrowser.close();
					opts.error && opts.error(err);
					console.log('fileBrowser err: ' + JSON.stringify(err));
				}
			});
		},
		apiPicture: function(opts) { // 拍照或相册
			var self = this;
			var sourceType = opts.sourceType || 'camera';
			var privacyType = '';
			var hasAuth = false;
			if (sourceType == 'camera') {
				privacyType = 'camera'
			} else {
				privacyType = 'photos'
			}
			self.privacy({
				type: privacyType,
				success: function(ret) {
					if (ret.status) {
						api.getPicture({
							sourceType: opts.sourceType,
							encodingType: opts.encodingType || 'jpg',
							mediaValue: opts.mediaValue || 'pic',
							destinationType: opts.destinationType || 'url',
							allowEdit: opts.allowEdit || false,
							quality: opts.quality || 100,
							targetWidth: opts.targetWidth || 500,
							targetHeight: opts.targetHeight || 500,
							saveToPhotoAlbum: opts.saveToPhotoAlbum || false
						}, function(ret, err) {
							if (ret) {
								opts.success && opts.success(ret);
							} else {
								if (err && err.msg == 'camera permission denied') {
									_g.toastMsg({msg: '请前往隐私设置开启“' + api.appName + '”的相机权限'});
								}
								if (err && err.msg == 'user canceled') {
									// 取消拍照
									// _g.toastMsg({msg: '获取图片失败，请重试！'});
								}
								opts.error && opts.error(err);
							}
						});
					}
				}
			})
		},
		docReader: function(opts) { // 文本阅读
			var docReader = api.require('docReader');
			docReader.open({
				path: opts.path
			}, function(ret, err) {
				if (ret.status) {
					opts.success && opts.success(ret);
				} else {
					if (err.code === 2) {
						_g.toastMsg({msg: '不支持该文件格式'});
					}
				}
			});
		},
		privacy: function(opts) { // IOS 平台上设备访问权限判断的接口
			if (api.systemType != 'ios') {
				opts.success && opts.success({
					status: 1
				})
				return;
			}
			var privacy = api.require('privacy');
			switch (opts.type) {
				case 'photos': // 相册
					privacy.photos(function(ret, err) {
						if (ret.status) {
							opts.success && opts.success(ret);
						} else {
							opts.error && opts.error(err)
							_g.toastMsg({msg: '请前往隐私设置开启“' + api.appName + '”的相册权限'});
						}
					});
					break;
				case 'camera': // 摄像头
					privacy.camera(function(ret, err) {
						if (ret.status) {
							opts.success && opts.success(ret);
						} else {
							opts.error && opts.error(err);
							_g.toastMsg({msg: '请前往隐私设置开启“' + api.appName + '”的相机权限'});
						}
					});
					break;
			}
		},
		scrollSelect: function(opts) { // 生成城市地区滑动选择器
			var self = this;
			var dataSource;
			var index;
			if (opts.isCitySelect) {
				$.ajax({
					type: 'get',
					url: '../../res/data/city.json',
					dataType: 'json',
					success: function(response) {
						var proData = _.find(response, { name: opts.curActive['pro'] }) || 0;
						var cityData = _.find(proData.sub, { name: opts.curActive['city'] }) || 0;
						var areaData = _.find(cityData.sub, { name: opts.curActive['area'] }) || 0;

						var proType = proData.type === undefined ? 0 : proData.type;
						var cityType = cityData.type === undefined ? 0 : cityData.type;
						var areaType = areaData.type === undefined ? 0 : areaData.type;

						index = [proType, cityType, areaType];
						dataSource = 'widget://res/data/city.json';
						self.openActionSelector({
							index: index,
							dataSource: dataSource,
							col: 3,
							nextStep: function(ret) {
								opts.nextStep && opts.nextStep(ret);
							}
						});
					},
					error: function(xhr, errorType, error) {
						console.log(JSON.stringify(xhr));
					}
				});
			} else {
				var curIndex = opts.curActive.index === undefined ? 0 : opts.curActive.index;
				self.openActionSelector({
					index: [curIndex],
					dataSource: opts.data,
					col: 1,
					nextStep: function(ret) {
						opts.nextStep && opts.nextStep(ret);
					}
				});
			}
		},
		openActionSelector: function(opts) { // 滑动选择器
			var UIActionSelector = api.require('UIActionSelector');
			UIActionSelector.open({
				datas: opts.dataSource,
				layout: {
					row: 5,
					col: opts.col,
					height: 30,
					size: 12,
					sizeActive: 14,
					rowSpacing: 5,
					colSpacing: 10,
					maskBg: 'rgba(0,0,0,0.2)',
					bg: '#fff',
					color: '#888',
					colorActive: '#f00',
					colorSelected: '#840B00'
				},
				animation: true,
				cancel: {
					text: '取消',
					size: 12,
					w: 90,
					h: 35,
					bg: '#fff',
					bgActive: '#ccc',
					color: '#888',
					colorActive: '#fff'
				},
				ok: {
					text: '确定',
					size: 12,
					w: 90,
					h: 35,
					bg: '#fff',
					bgActive: '#840B00',
					color: '#888',
					colorActive: '#fff'
				},
				title: {
					text: '请选择',
					size: 12,
					h: 44,
					bg: '#eee',
					color: '#888'
				},
				actives: opts.index,
				fixedOn: api.frameName
			}, function(ret, err) {
				if (ret) {
					opts.nextStep && opts.nextStep(ret);
					UIActionSelector.close();
				} else {
					_g.toastMsg(err.msg);
				}
			});
		},
		multiSeletor: function(opts) { // 多选的选择器
			$(opts.dataSource).each(function(index, dataItem) {
				dataItem['status'] = 'normal';
			});
			$(opts.dataSource).each(function(index, dataItem) {
				$(opts.selectData).each(function(index, selectItem) {
					if (dataItem.text == selectItem) {
						dataItem['status'] = 'selected';
						return;
					}
				});
			});

			var UIMultiSelector = api.require('UIMultiSelector');
			UIMultiSelector.open({
				rect: {
					h: 244
				},
				text: {
					title: '',
					leftBtn: '取消',
					rightBtn: '确定',
					selectAll: '全选'
				},
				max: 50,
				singleSelection: false,
				styles: {
					//bg:'' 				//（可选项）字符串类型；主体的背景，支持 rgb，rgba，#，widget://，fs://；默认：#fff
					mask: 'rgba(0,0,0,0)', //（可选项）字符串类型；遮罩层的背景，支持 rgb、rgba、#、img；默认：rgba(0,0,0,0)
					title: { //（可选项）JSON 类型；标题栏样式；默认：见内部字段
						bg: '#FFFFFF',
						color: '#fff',
						size: 16,
						h: 44
					},
					leftButton: {
						w: 80,
						h: 35,
						bg: '#fff', //（可选项）字符串类型；按钮的背景，支持 rgb、rgba、#、img；默认：#f00
						marginT: 5, //（可选项）数字类型；按钮的上边距；默认：5
						marginL: 8,
						color: '#222',
						size: 14
					},
					rightButton: {
						w: 80,
						h: 35,
						bg: '#fff',
						marginT: 5,
						marginR: 8,
						color: '#840B00',
						size: 14
					},
					item: {
						h: 35, //（可选项）数字类型；按钮的高度；默认：35
						bg: '#e5e5e5', //（可选项）字符串类型；选项的背景，支持 rgb、rgba、#、img；默认：#fff
						// bgActive: '#e5e5e5',			//（可选项）字符串类型；已选中选项的背景，支持 rgb、rgba、#、img；默认：bg
						bgHighlight: 'rgb(238,17,150)', //（可选项）字符串类型；选项的高亮背景，支持 rgb、rgba、#、img；默认：bg
						color: '#222', //（可选项）字符串类型；选项的文字颜色，支持 rgb，rgba，#；默认：#444
						active: '#840B00', //（可选项）字符串类型；已选中选项的文字颜色，支持 rgb、rgba、#；默认：color
						highlight: 'rgb(255,255,0)', //（可选项）字符串类型；选项的高亮文字颜色，支持 rgb、rgba、#；默认：color
						size: 14, //（可选项）数字类型；选项的文字大小；默认：14
						lineColor: '#e5e5e5', //（可选项）字符串类型；分隔线的颜色，支持 rgb、rgba、#；默认：rgba(0,0,0,0)
						textAlign: 'center' //（可选项）字符串类型；选项文字的对齐方式，'left|center|right'，当值为 left 或 right 
							//时文字会根据情况空留 icon 已占的位置；默认：left
					},
					icon: { //（可选项）JSON 类型；每个选项的状态图标样式，若不传则不显示选中的状态图标
						w: 20,
						h: 20,
						marginT: 5,
						marginH: 33,
						bg: 'widget://image/item-default.png', //（可选项）字符串类型；图标未选中时的背景，支持 rgb、rgba、#、img；默认：rgba(0,0,0,0)
						bgActive: 'widget://image/item-checked.png', //（可选项）字符串类型；已选中图标的背景，支持 rgb、rgba、#、img；默认：bg
						align: 'left' //（可选项）字符串类型；图标相对与选项的对齐方式：'left|right'；默认：left
					}
				},
				animation: true,
				items: opts.dataSource
			}, function(ret, err) {
				if (ret) {
					if (ret.eventType == 'clickRight') {
						opts.callback && opts.callback(ret.items);
						UIMultiSelector.close();
					} else if (ret.eventType == 'clickLeft') {
						UIMultiSelector.close();
					}
				} else {
					console.log(JSON.stringify(err));
				}
			});
		},
		screenClip: function(opts) { // 屏幕截图，生成图片
			var screenClip = api.require('screenClip');
			screenClip.screenShot({
				album: true,
				imgPath: 'fs://jietu/',
				imgName: 'funnel.png'
			}, function(ret, err) {
				var url = api.fsDir + '/jietu/funnel.png';
				if (ret.status) {
					opts.success && opts.success(url);
				} else {
					console.log(JSON.stringify(err));
				}

			});
		},
		scan: function(opts) { // 二维码/条形码扫描
			var FNScanner = api.require('FNScanner');
			FNScanner.openScanner({
				autorotation: true,
			}, function(ret, err) {
				if (ret) {
					if (ret.eventType == 'success') {
						opts.success && opts.success(ret);
					} else if (ret.eventType == 'show') {
						_g.toastMsg({
							msg: '扫描开始'
						});
					} else {
						opts.error && opts.error(err);
					}
				} else {
					console.log(_g.j2s(err));
				}
			});
		}
	}

	Modules.prototype.constructor = Modules;
	module.exports = new Modules();
});
